*******************************
***** "Chile 2022" ***** 
******************************
clear
set more off
set type double
cap log close

scalar t1 = c(current_time)

local dir0 "" //Ruta de carpeta para revisión
local dir1 "" //Ruta para guardar bases intermedias y final,  archivo SAP
local dir2 "" //Ruta de base de datos original


cap log close 
log using "`dir2'\\generacion_ca22db06_2022.log", text replace


/*Programa outsum: 
	   Sintaxis:
	   outsm var [aweight/], st(string) vars(string) name("string") [ifsum(string) ifpre(string)]

	   General:
	   El programa "outsum" se ha creado para revisar valores extremos de variables de ingreso por individuo con el fin de determinar posibles datos atípicos según 
	   las características del individuo. En resumen, se selecciona la variable de ingreso a revisar (var), las estadísticas descriptivas de la variable (st), otras 
	   variables con el fin de identificar al individuo (Folio, edad, codact, entre otras) (vars) y el nombre del archivo Excel (name) al cual se van a exportar los datos.

	   Como resultado, se obtienen tres tablas:
	   - A la izquierda, se obtiene una tabla con las observaciones que están desde el percentil 99 en adelante, con sus respectivas variables descriptivas.
	   - En medio, se obtiene el resumen estadístico de la variable de ingreso, como su media, mínimo, máximo, etc.
	   - A la derecha, se obtiene una tabla con las observaciones que están desde el percentil 1 hacia atrás (valores mayores a 0), con sus respectivas variables descriptivas.
	   - Tanto la tabla de la izquierda como la de la derecha contienen una variable llamada "etiqueta" que entrega la etiqueta de la variable extraída desde la misma variable.

	   Nota: El nombre de la hoja de Excel es igual al de la variable.

	   Opcional:
	   ifsum: Especifica condiciones para el cálculo de los percentiles y las estadísticas descriptivas, por ejemplo, que se calcule solo para asalariados.
	   ifpre: Especifica condiciones tipo filtro para la salida de las tablas de Excel, por ejemplo, que muestre los resultados para individuos que trabajan desde 35 horas en adelante.

	   Nota: "ifsum" no interfiere con "ifpre". Si requiere que tanto el dato como la salida estén condicionados, debe aplicar la misma condición en ambas, aunque no necesariamente de manera idéntica.
*/

cap prog drop outsm
prog define outsm

	**************************************************************************************************

	qui {
		syntax varlist (min=1) [aweight/] ,    ST(string) VARS(string) NAME(string) [ IFSUM(string) IFPRE(string) ]

		tempvar peso 
		local abc = "A B C D E F G H I J K L M N O P Q R S T U V W X Y Z AA AB AC AD"

		local N_vars = wordcount("`varlist' `vars'")
		local nc_tab1 = `N_vars' + 3 
		local ltab1 = word("`abc'", `nc_tab1')
		local nc_tab2 = `nc_tab1' + 4 
		local ltab2   = word("`abc'", `nc_tab2')

		if "`weight'" == "" gen `peso' = 1 
		else 			  gen `peso' = `exp'

		/*Opcionales if*/
		if "`ifsum'"== "" local ifsum 
		else local ifsum  & `ifsum'

		if "`ifpre'"== "" local ifpre 
		else local ifpre  & `ifpre'

		sum `varlist' [aw = `peso'] if `varlist' > 0 & `varlist' < . `ifsum'  , detail 
		local p1  = r(p1)
		local p99 = r(p99)
		preserve

		clear 
		set obs 100
		gen summ = ""
		gen dato = .
		local count = 1 
		noi noi noi display "lista `st'"
		local list = "`st'"
		foreach cat of local list {

			noi display "`cat'"

			replace summ = "`cat'" in `count'
			replace dato = ``cat'' in `count'

			local count = 1 + `count'

		}
		keep if dato != .
		* noi list 
		if _N > 0  export excel using "`name'", sheet("`varlist'") sheetreplace firstrow(variables)  keepcellfmt cell(`ltab1'3)
		restore 


		gsort - `varlist'

		local lab: variable label `varlist'
		gen etiqueta = "`lab'" if `varlist' >= `p99' & `varlist' < . `ifpre' 
		bys etiqueta: replace etiqueta = "" if _n > 1 

		cap export excel  `vars'  `varlist' etiqueta  using "`name'" if `varlist' >= `p99' & `varlist' < . `ifpre' , sheet("`varlist'") sheetmodify firstrow(variables)  keepcellfmt


		cap drop etiqueta

		gsort + `varlist'

		local lab: variable label `varlist'
		gen etiqueta = "`lab'"  if `varlist' > 0 & `varlist' <= `p1' `ifpre' 
		bys etiqueta: replace etiqueta = "" if _n > 1 

		cap export excel  `vars' `varlist' etiqueta using "`name'" if `varlist' > 0 & `varlist' <= `p1' `ifpre' , sheet("`varlist'") sheetmodify firstrow(variables)  keepcellfmt cell(`ltab2'1)

		cap drop etiqueta


	}	 
end



local stlist = "r(N) r(mean) r(min) r(p1) r(p50) r(p99) r(max)"

/*Para correr programa por partes*/

local part1 = 1
local part2 = 1
local part3 = 1
local part4 = 1
local part5 = 1
local part6 = 1

local validaciones = 0		//1 ->Corre programa outsum

qui{

	if `part1' == 1 {

		noi display "------PARTE 1"

		//Corrección de asignación de tope de SAP
		import excel using "`dir1'\\SAP_2022", sh(Base) first
		mkmat *, matrix(SAP)

		matrix list SAP

		*******************************
		****** "Creación dn01" ********
		*******************************

		*use "`dir2'\\230508_base_casen_2022_cepal", clear  			/*versión preliminar, recibida 10 mayo 2023*/
		*noi use "`dir2'\\230601_base_casen_2022_cepal", clear  		/*versión preliminar, recibida 1 junio 2023*/
		*noi use "`dir2'\\230613_base_casen_2022_cepal_fe", clear  		/*versión final con fe, recibida 13 junio 2023*/
		*noi use "`dir2'\\230622_base_casen_2022_cepal_fe_var", clear  	/*versión final con fe, y recuperación de casos recibida 27 junio 2023*/
		noi use "`dir2'230630_base_casen_2022_cepal_fe_var", clear  	/*versión final con fe, y recuperación de casos recibida 3 julio 2023*/


		/*Edición casos especiales*/

		/*Corrección variable y28_1c2monto de 193197 a 193917 */
		
		replace y28_1c2monto = 193917 if y28_1c2monto != . // 18/07/2023 por pedido de MDSF
		
		/*Subsidio agua potable*/

		noi display _newline(2) "Subsidio Agua Potable" _newline(2)

		gen y24_o = y24 

		local casos = rowsof(SAP)

		forval x = 1/ `casos'  {
			replace y24 = SAP[`x',2] if comuna == SAP[`x',1] & y24> SAP[`x',2] & y24>0 & y24!=99 & y24!=. // nota: el NSNR es -88 no 99 
			replace y24 = round(y24,1)
		}
		gen aux_SAP = y24 - y24_o 
		sum aux_SAP
		assert r(max) <= 0 & r(N) > 0 
		sum aux_SAP if aux_SAP < 0 
		noi display "El truncamiento provoca una disminución de " abs(r(mean)) " en promedio para las " r(N) " Obs truncadas, con disminuciones entre " r(min) " y " r(max)

		preserve

		keep if aux_SAP <0 
		keep folio y24  y24_o aux_SAP 
		gsort  aux_SAP
		export excel using "`dir0'\Variables Truncadas.xlsx", sheet("aux_SAP") sheetmodify firstrow(variables) keepcellfmt

		restore 

		drop aux_SAP


		/*Bono trabajo mujer*/ 

		noi display _newline(2) "Bono trabajo mujer" _newline(2)

		gen y25f_o = y25f
		replace y25f = 35677 if inlist(y25fp,1,-88) & y25f > 35677 & y25f!=. //el 9 ya no es nsnr 	
		replace y25f = 534981 if y25fp == 2 & y25f > 534981	& y25f!=.		

		gen aux_BTM = y25f - y25f_o 
		sum aux_BTM
		assert r(max) <= 0 & r(N) > 0

		sum aux_BTM if aux_BTM < 0 & inlist(y25fp,1,-88)
		noi display "El truncamiento provoca una disminución de " abs(r(mean)) " en promedio para las " r(N) " Obs truncadas, con disminuciones entre " r(min) " y " r(max) " Para periodicidad mensual"

		sum aux_BTM if aux_BTM < 0 & inlist(y25fp,2,-88)
		noi display "El truncamiento provoca una disminución de " abs(r(mean)) " en promedio para las " r(N) " Obs truncadas, con disminuciones entre " r(min) " y " r(max) " Para periodicidad anual"

		preserve

		keep if aux_BTM <0 
		keep folio y25f   y25f_o y25fp aux_BTM 
		gsort  y25fp aux_BTM
		export excel using "`dir0'\Variables Truncadas.xlsx", sheet("aux_BTM") sheetmodify firstrow(variables) keepcellfmt

		restore 

		drop aux_BTM

		/*Subsidio empleo joven*/ 

		noi display _newline(2) "Subsidio empleo jóven" _newline(2)

		gen y25e_o = y25e
		replace y25e = 35677 if inlist(y25ep,1,-88) & y25e> 35677	& y25e!=.	// -88
		replace y25e = 534981 if y25ep == 2 & y25e > 534981	& y25e!=.		

		gen aux_SEJ = y25e - y25e_o 
		sum aux_SEJ
		assert r(max) <= 0 & r(N) > 0

		sum aux_SEJ if aux_SEJ < 0 & inlist(y25ep,1,-88)
		noi display "El truncamiento provoca una disminución de " abs(r(mean)) " en promedio para las " r(N) " Obs truncadas, con disminuciones entre " r(min) " y " r(max) " Para periodicidad mensual"

		sum aux_SEJ if aux_SEJ < 0 & inlist(y25ep,2,-88)
		noi display "El truncamiento provoca una disminución de " abs(r(mean)) " en promedio para las " r(N) " Obs truncadas, con disminuciones entre " r(min) " y " r(max) " Para periodicidad anual"

		preserve

		keep if aux_SEJ <0 
		keep folio y25e   y25e_o y25ep aux_SEJ 
		gsort  y25ep aux_SEJ
		export excel using "`dir0'\Variables Truncadas.xlsx", sheet("aux_SEJ") sheetmodify firstrow(variables) keepcellfmt

		restore 

		drop aux_SEJ


		/*Ingreso mínimo garantizado*/ 

		noi display _newline(2) "Ingreso mínimo garantizado" _newline(2)

		gen y25g_o = y25g
		replace y25g = 71850 if y25g>71850 & y25g!=.

		gen aux_IMG = y25g - y25g_o 
		sum aux_IMG
		assert r(max) <= 0 & r(N) > 0 
		sum aux_IMG if aux_IMG < 0 
		noi display "El truncamiento provoca una disminución de " abs(r(mean)) " en promedio para las " r(N) " Obs truncadas, con disminuciones entre " r(min) " y " r(max)

		preserve

		keep if aux_IMG  <0 
		keep folio y25g  y25g_o aux_IMG 
		gsort  aux_IMG 
		export excel using "`dir0'\Variables Truncadas.xlsx", sheet("aux_IMG ") sheetmodify firstrow(variables) keepcellfmt

		restore 

		drop aux_IMG


		save "`dir1'\ca22dn01.dta", replace

	}

	****************************************************************************************************************************************
	***** "Creación de dn02:generación de variables estandarizadas(factorex, id_hogar, id_pers, condact, ocupr, ramar, categ, anoest)" ***** 
	***** "y generación de variables de ingreso mensualizadas a nivel persona"                     									   *****
	****************************************************************************************************************************************

	if `part2' == 1 {

		noi display "Parte 2"
		cap confirm file "`dir1'\ca22dn01.dta"
		if _rc != 0 continue 

		use "`dir1'\\ca22dn01.dta", clear


		/* Construccion variables CEPAL*/

		/*Generación de mes y anio de levantamiento de ingresos*/
		gen mes = substr(fecha_inicio_y,6,2)
		gen anio = substr(fecha_inicio_y,1,4)

		gen factorex = expr

		bysort folio: gen id_hog = (_n == 1)
		gen id_hogar = sum( id_hog)
		drop id_hog

		duplicates report

		rename id_persona id_persona_orig
		sort id_hogar id_persona_orig
		by id_hogar: gen id_persona = _n

		gen parentco = pco1



		/*REVISIÓN DE VARIABLES DE EDAD Y SEXO*/

		tab edad,m
		tab sexo,m	


		/*VALIDACION*/
		quietly: count if parentco == .
		if r(N) {
			noi display in red _newline(1) ///
				"***ERROR: Problema al crear PARENTCO en " r(N) " observaciones."

			noi tabulate pco1, missing nolabel

			display in red _newline(1) "***ERROR: Proceso cancelado"
			exit 20001
		}


		/* Condición de actividad */ 
		gen condact = 0 if edad < 15 									/* Menores de 15, no aplica (cambia respecto a 2015, menores de 12)*/
		replace condact = 1 if o1 == 1| o2 == 1 |o3 == 1 				/* Ocupados*/
		replace condact = 2 if o6 == 1 & (o4 == 1| o4 == 9)				/* Desocupados - cesante*/ // nota1: no hay cat 9					
		replace condact = 3 if o6 == 1 & o4 == 2 						/* Desocupados - Buscan primera vez */				
		replace condact = 3 + o7 if (o7	>=1 & o7 <= 19)					/* Inactivos*/				
		replace condact = 99 if condact ==. & o7 == .					/* Ignorado */

		label define condact 0"Menor de 15 años" 1"Ocupado" 2"Cesante" 3"Busca por primera vez" 4"Consiguio trabajo, empezara pronto" 5"Esperando resultado de gestiones" /*
			*/ 6"No tiene con quien dejar a los niños" 7"No tiene con quien dejar adulto mayor" 8"No tiene con quien dejar otro familiar" 9 "Enfermo o discapacitado" /*
			*/ 10"Piensa que nadie le dara trabajo" 11"Condiciones laborales no le acomodan" 12"Ofrecen sueldos muy bajos" 13"Quehaceres del hogar" 14"Estudiante" /*
			*/ 15"Jubilado(a), pensionado(a) o montepiado(a)" 16"Tiene otra fuente de ingreso" 17"Por temor a contagiarse de COVID-19" 18"Se canso de buscar o cree que no hay trabajo disponible" /*
		*/ 19"Cree que no hay trabajo disponible" 20"Busca cuando lo necesita o tiene trabajo esporadico" 21"No tiene interes en trabajar" 22"Otra razon" 99"NS/NR"

		label values condact condact

		/*VALIDACION*/
		quietly: count if condact == .
		if r(N) {
			noi display in red _newline(1) ///
				"***ERROR: Problema al crear CONDACT en " r(N) " observaciones."

			noi list edad o1 o2 o3 o6 o4 o5 o7  ///
				if condact == ., nolabel abbreviate(32)

			noi display in red _newline(1) "***ERROR: Proceso cancelado"
			exit 20002
		}


		/*Ocupacion primaria a un digito. CIUO 08*/

		gen ocupr = cond(condact == 1, oficio1_08, -1)
		replace ocupr = 99 if  inlist(ocupr,-99, -88, -66) 

		label define ocup 0 "Fuerzas Armadas" 1 "Gerentes" 2 "Profesionales" 3 "Técnicos y profesionales asociados" 4 "Trabajadores de apoyo administrativo" /*
			*/5 "Trabajadores de servicios y ventas" 6 "Trabajadores calificados de la agricultura, la silvicultura y la pesca" 7 "Trabajadores de artesanía y oficios conexos" /*
		*/8 "Operadores de plantas y máquinas y ensambladores" 9 "Ocupaciones elementales" -1 "NA" 98 "No bien especificado" 99 "NS/NR"

		label value ocupr ocup

		/* VALIDACION*/
		quietly: count if ocupr == .
		if r(N) {
			noi display in red _newline(1) ///
				"***ERROR: Problema al crear OCUPR en " r(N) " observaciones."

			noi tabulate oficio1_08 condact ///
				if ocupr == ., missing nolabel

			noi display in red _newline(1) "***ERROR: Proceso cancelado"
			exit 20003
		}


		/* Creacion de RAMA. CIIU Rev 3*/ /*SE CAMBIA A REV 4 y se toma la variable a un digito directamente*/


		gen ramar = cond(condact == 1, rama1, -1)
		replace ramar = 99 if inlist(ramar,-99, -88, -66) 

		label define RAMA 1 "Agricultura, ganadería silvicultura y pesca" ///
			2 "Explotación de minas y canteras" ///
			3 "Industrias manufactureras" ///
			4 "Suministro de electricidad, gas, vapor y aire acondicionado" ///
			5 "Suministro de agua; evacuación de aguas residuales, gestión de desechos y descontaminación" ///
			6 "Construcción" ///
			7 "Comercio al por mayor y al por menor, reparación de vehículos automotores y motocicletas" ///
			8 "Transporte y almacenamiento" ///
			9 "Actividades de alojamiento y de servicio de comidas" ///
			10 "Información y comunicaciones" ///
			11 "Actividades financieras y de seguros" ///
			12 "Actividades inmobiliarias" ///
			13 "Actividades profesionales, científicas y técnicas" ///
			14 "Actividades de servicios administrativos y de apoyo" ///
			15 "Administración pública y defensa; planes de seguridad social de afiliación obligatoria" ///
			16 "Enseñanza" ///
			17 "Actividades de atención de la salud humana y de asistencia social" ///
			18 "Actividades artísticas, de entretenimiento y recreativas" ///
			19 "Otras actividades de servicios" ///
			20 "Los hogares como empleadores" ///
			21 "Actividades de organizaciones y órganos extraterritoriales" ///
			-1 "NA" 88 "No bien especificado" 99 "NS/NR"

		label values ramar RAMA

		/*VALIDACION*/
		quietly: count if ramar == .
		if r(N) {
			noi display in red _newline(1) ///
				"***ERROR: Problema al crear RAMAR en " r(N) " observaciones."

			tabulate rama1 condact ///
				if rama_p == ., missing nolabel

			noi display in red _newline(1) "***ERROR: Proceso cancelado"
			exit 20004
		}


		/*Creación CATEG*/ 

		gen categ = cond((condact==1 & o15 >=1 & o15 <=9), o15, -1)
		replace categ = 99 if categ == .

		label define categ 1"Patron o empleador" 2 "Trabajador por cuenta propia" 3 "Empleado u obrero del sector publico" 4 "Empleado u obrero de empresas publicas" 5 "Empleado u obrero del sector privado" /*
		*/ 6 "Servicio domestico puertas adentro" 7"Servicio domestico puertas afuera" 8"FF.AA. y del orden" 9"Familiar no remunerado" -1"NA" 99"NS/NR"
		label values categ categ
		tab categ, miss

		/*VALIDACION*/	
		quietly: count if categ == .
		if r(N) {
			noi display in red _newline(1) ///
				"***ERROR: Problema al crear CATEG en " r(N) " observaciones."

			tabulate condact o15 ///
				if categ == ., missing nolabel

			noi display in red _newline(1) "***ERROR: Proceso cancelado"
			exit 2005
		}	

		/*Creación ANOEST*/

		/*ANOEST TRADICIONAL*/
		/*Asisten actualmente*/
		/*Curso que estudia actualmente: si la encuesta es realizada en nov debería  restarse uno, si es en enero ya completó el curso*/

		bysort e6a_asiste: tab e6b_asiste, m nol
		bysort e6a_no_asiste: tab e6b_no_asiste, m nol

		gen anoest_trad = cond(e6a_asiste >= 2 & e6a_asiste <=4, 0, .)
		replace anoest_trad = 99 if e6a_asiste == 5													/*Educacion especial*/
		replace anoest_trad = e6b_asiste if e6a_asiste == 7 	& e6b_asiste>=1 & e6b_asiste<=8			/*Educación básica*/ 
		replace anoest_trad = 99 if e6a_asiste == 7 	& e6b_asiste == -88 & anoest_trad == .
		replace anoest_trad = 8 + e6b_asiste if e6a_asiste == 9  & e6b_asiste>=1 & e6b_asiste<=4		/*Educación media Científico-Humanista*/
		replace anoest_trad = 8 if e6a_asiste == 9  & e6b_asiste == -88 & anoest_trad == . 
		replace anoest_trad = 8 + e6b_asiste if e6a_asiste == 11  & e6b_asiste>=1 & e6b_asiste<=5	/*Educación Media Técnica Profesional*/
		replace anoest_trad = 8 if e6a_asiste == 11  & e6b_asiste == -88 & anoest_trad == .
		replace anoest_trad = 12 + e6b_asiste if e6a_asiste == 12 & e6b_asiste>=1 & e6b_asiste<=3	/* Técnico Nivel Superior (Carreras 1 a 3 años)*/
		replace anoest_trad = 12 if e6a_asiste == 12 & e6b_asiste == -88 & anoest_trad == .
		replace anoest_trad = 12 + e6b_asiste if e6a_asiste == 13 & e6b_asiste>=1 & e6b_asiste<=10	/* Profesional (Carreras 4 o más años)*/
		replace anoest_trad = 12 if e6a_asiste == 13 & e6b_asiste == -88 & anoest_trad == .
		replace anoest_trad = 17 + e6b_asiste if e6a_asiste == 14 & e6b_asiste>=1 & e6b_asiste<=4	/* Magíster o maestría*/
		replace anoest_trad = 17 if e6a_asiste == 14 & e6b_asiste == -88 & anoest_trad == .
		replace anoest_trad = 17 + e6b_asiste if e6a_asiste == 15 & e6b_asiste>=1 & e6b_asiste<=6	/* Doctorado*/

		/*No asisten*/

		//bysort e6a_no_asiste:tab e6b_no_asiste,m nol

		replace anoest_trad = 0 if e6a_no_asiste >= 1 & e6a_no_asiste <=4 & anoest_trad ==. 
		replace anoest_trad = 99 if e6a_no_asiste == 5 & anoest_trad ==. 															/*Educacion especial*/
		replace anoest_trad = e6b_no_asiste if e6a_no_asiste == 6 & e6b_no_asiste>=1 & e6b_no_asiste<=6	& anoest_trad ==.			/*Primaria o Preparatoria (Sistema antiguo)*/
		replace anoest_trad = 99 if e6a_no_asiste == 6 & e6b_no_asiste== -88 & anoest_trad ==.
		replace anoest_trad = e6b_no_asiste if e6a_no_asiste == 7 & e6b_no_asiste>=1 & e6b_no_asiste<=8	& anoest_trad ==.			/*Educación básica*/ 
		replace anoest_trad = 99 if e6a_no_asiste == 7 & e6b_no_asiste == -88 & anoest_trad ==.
		replace anoest_trad = 6 + e6b_no_asiste if e6a_no_asiste == 8 & e6b_no_asiste>=1 & e6b_no_asiste<=6	& anoest_trad ==.		/*Humanidades (Sistema Antiguo)*/
		replace anoest_trad = 6 if e6a_no_asiste == 8 & e6b_no_asiste == -88	& anoest_trad ==.
		replace anoest_trad = 6 + e6b_no_asiste if e6a_no_asiste == 10 & e6b_no_asiste>=1 & e6b_no_asiste<=6 & anoest_trad ==.		/*Técnica, Comercial, Industrial o Normalista (Sistema Antiguo)*/
		replace anoest_trad = 6 if e6a_no_asiste == 10 & e6b_no_asiste ==-88 & anoest_trad ==.
		replace anoest_trad = 8 + e6b_no_asiste if e6a_no_asiste == 9 & e6b_no_asiste>=1 & e6b_no_asiste<=4	& anoest_trad ==.		/*Educación media Científico-Humanista*/
		replace anoest_trad = 8 if e6a_no_asiste == 9 & e6b_no_asiste == -88	& anoest_trad ==.
		replace anoest_trad = 8 + e6b_no_asiste if e6a_no_asiste == 11 & e6b_no_asiste>=1 & e6b_no_asiste<=5 & anoest_trad ==.		/*Educación Media Técnica Profesional*/
		replace anoest_trad = 8 if e6a_no_asiste == 11 & e6b_no_asiste == -88 & anoest_trad ==.
		replace anoest_trad = 12 + e6b_no_asiste if e6a_no_asiste == 12 & e6b_no_asiste>=1 & e6b_no_asiste<=3 & anoest_trad ==.		/* Técnico Nivel Superior (Carreras 1 a 3 años)*/
		replace anoest_trad = 14 if e6a_no_asiste == 12 & e6b_no_asiste == -88 & anoest_trad ==. & e6c_completo == 1
		replace anoest_trad = 12 if e6a_no_asiste == 12 & e6b_no_asiste == -88 & anoest_trad ==. & e6c_completo == 2
		replace anoest_trad = 12 + e6b_no_asiste if e6a_no_asiste == 13 & e6b_no_asiste>=1 & e6b_no_asiste<=10 & anoest_trad ==.						/* Profesional (Carreras 4 o más años)*/
		replace anoest_trad = 16 if e6a_no_asiste == 13  & e6b_no_asiste == -88 & anoest_trad ==. & e6c_completo == 1
		replace anoest_trad = 12 if e6a_no_asiste == 13  & e6b_no_asiste == -88 & anoest_trad ==. & e6c_completo == 2
		replace anoest_trad = 16 + e6b_no_asiste if e6a_no_asiste == 14 & e6b_no_asiste>=1 & e6b_no_asiste<=4 & anoest_trad ==.		/* Magíster o maestría*/
		replace anoest_trad = 18 if e6a_no_asiste == 14 & e6b_no_asiste == -88 & anoest_trad ==. & e6c_completo == 1
		replace anoest_trad = 16 if e6a_no_asiste == 14 & e6b_no_asiste == -88 & anoest_trad ==. & e6c_completo == 2
		replace anoest_trad = 16 + e6b_no_asiste if e6a_no_asiste == 15 & e6b_no_asiste>=1 & e6b_no_asiste<=6 & anoest_trad ==.	 	/* Doctorado*/
		replace anoest_trad = 21 if e6a_no_asiste == 15 & e6b_no_asiste == -88 & anoest_trad ==.	& e6c_completo ==1
		replace anoest_trad = 16 if e6a_no_asiste == 15 & e6b_no_asiste == -88 & anoest_trad ==.	& e6c_completo ==2


		/*ANOEST NUEVO : USA VBLES e6d_preg y e6d_postg*/

		/*ASISTEN*/
		gen anoest = cond(e6a_asiste >= 2 & e6a_asiste <=4, 0, .)								// sala cuna, jardín indantil y prekinder/kinder
		replace anoest = 99 if e6a_asiste == 5													/*Educacion especial*/
		replace anoest = e6b_asiste if e6a_asiste == 7 	& e6b_asiste>=1 & e6b_asiste<=8		/*Educación básica*/ 
		replace anoest = 99 if e6a_asiste == 7 	& e6b_asiste == -88 & anoest == .
		replace anoest = 8 + e6b_asiste if e6a_asiste == 9  & e6b_asiste>=1 & e6b_asiste<=4	/*Educación media Científico-Humanista*/
		replace anoest = 8 if e6a_asiste == 9  & e6b_asiste == -88 & anoest == . 
		replace anoest = 8 + e6b_asiste if e6a_asiste == 11  & e6b_asiste>=1 & e6b_asiste<=5	/*Educación Media Técnica Profesional*/
		replace anoest = 8 if e6a_asiste == 11  & e6b_asiste == -88 & anoest == .
		replace anoest = 12 + e6b_asiste if e6a_asiste == 12 & e6b_asiste>=1 & e6b_asiste<=3	/* Técnico Nivel Superior (Carreras 1 a 3 años)*/
		replace anoest = 12 if e6a_asiste == 12 & e6b_asiste == -88 & anoest == .
		replace anoest = 12 + e6b_asiste if e6a_asiste == 13 & e6b_asiste>=1 & e6b_asiste<=10	/* Profesional (Carreras 4 o más años)*/
		replace anoest = 12 if e6a_asiste == 13 & e6b_asiste == -88 & anoest == .

		replace anoest = 12 + e6d_preg + e6b_asiste if e6a_asiste == 14 & e6b_asiste>=1 & e6b_asiste<=4 & e6d_preg>0 & e6d_preg<.	/* Magíster o maestría*/ 
		replace anoest = 17 + e6b_asiste if e6a_asiste == 14 & e6b_asiste>=1 & e6b_asiste<=4 & e6d_preg == -88
		replace anoest = 17 if e6a_asiste == 14 & e6b_asiste == -88 & anoest == .

		replace anoest = 12 + e6d_preg + e6d_postg + e6b_asiste if e6a_asiste == 15 & e6b_asiste>=1 & e6b_asiste<=6 & e6d_preg>0 & e6d_preg<. & e6d_postg>=0 & e6d_postg<. & anoest == .	/* Doctorado*/ //a001

		replace anoest = 14 + e6d_preg + e6b_asiste if e6a_asiste == 15 & e6b_asiste>=1 & e6b_asiste<=6 & e6d_preg>0 & e6d_preg<. & e6d_postg == -88 & anoest == .
		replace anoest = 17 + e6b_asiste if e6a_asiste == 15 & e6b_asiste>=1 & e6b_asiste<=6 & anoest == .


		/*NO ASISTEN*/

		replace anoest = 0 if e6a_no_asiste >= 1 & e6a_no_asiste <=4 & anoest ==. 
		replace anoest = 99 if e6a_no_asiste == 5 & anoest ==. 															/*Educacion especial*/
		replace anoest = e6b_no_asiste if e6a_no_asiste == 6 & e6b_no_asiste>=1 & e6b_no_asiste<=6	& anoest ==.			/*Primaria o Preparatoria (Sistema antiguo)*/
		replace anoest = 99 if e6a_no_asiste == 6 & e6b_no_asiste== -88 & anoest ==.
		replace anoest = e6b_no_asiste if e6a_no_asiste == 7 & e6b_no_asiste>=1 & e6b_no_asiste<=8	& anoest ==.			/*Educación básica*/ 
		replace anoest = 99 if e6a_no_asiste == 7 & e6b_no_asiste == -88 & anoest ==.
		replace anoest = 6 + e6b_no_asiste if e6a_no_asiste == 8 & e6b_no_asiste>=1 & e6b_no_asiste<=6	& anoest ==.		/*Humanidades (Sistema Antiguo)*/
		replace anoest = 6 if e6a_no_asiste == 8 & e6b_no_asiste == -88	& anoest ==.
		replace anoest = 6 + e6b_no_asiste if e6a_no_asiste == 10 & e6b_no_asiste>=1 & e6b_no_asiste<=6 & anoest ==.		/*Técnica, Comercial, Industrial o Normalista (Sistema Antiguo)*/
		replace anoest = 6 if e6a_no_asiste == 10 & e6b_no_asiste ==-88 & anoest ==.
		replace anoest = 8 + e6b_no_asiste if e6a_no_asiste == 9 & e6b_no_asiste>=1 & e6b_no_asiste<=4	& anoest ==.		/*Educación media Científico-Humanista*/
		replace anoest = 8 if e6a_no_asiste == 9 & e6b_no_asiste == -88	& anoest ==.
		replace anoest = 8 + e6b_no_asiste if e6a_no_asiste == 11 & e6b_no_asiste>=1 & e6b_no_asiste<=5 & anoest ==.		/*Educación Media Técnica Profesional*/
		replace anoest = 8 if e6a_no_asiste == 11 & e6b_no_asiste == -88 & anoest ==.
		replace anoest = 12 + e6b_no_asiste if e6a_no_asiste == 12 & e6b_no_asiste>=1 & e6b_no_asiste<=3 & anoest ==.		/* Técnico Nivel Superior (Carreras 1 a 3 años)*/
		replace anoest = 15 if e6a_no_asiste == 12 & e6b_no_asiste == -88 & anoest ==. & e6c_completo == 1
		replace anoest = 12 if e6a_no_asiste == 12 & e6b_no_asiste == -88 & anoest ==. & e6c_completo == 2
		replace anoest = 12 + e6b_no_asiste if e6a_no_asiste == 13 & e6b_no_asiste>=1 & e6b_no_asiste<=10 & anoest ==.						/* Profesional (Carreras 4 o más años)*/
		replace anoest = 17 if e6a_no_asiste == 13  & e6b_no_asiste == -88 & anoest ==. & e6c_completo == 1
		replace anoest = 12 if e6a_no_asiste == 13  & e6b_no_asiste == -88 & anoest ==. & e6c_completo == 2

		replace anoest = 12 + e6d_preg + e6b_no_asiste if e6a_no_asiste == 14 & e6b_no_asiste>=1 & e6b_no_asiste<=4 & anoest ==. & e6d_preg>0 & e6d_preg<.	/* Magíster o maestría*/
		replace anoest = 17 + e6b_no_asiste if e6a_no_asiste == 14 & e6b_no_asiste>=1 & e6b_no_asiste<=4 & anoest ==. & e6d_preg == -88
		replace anoest = 19 if e6a_no_asiste == 14 & e6b_no_asiste == -88 & anoest ==. & e6c_completo == 1
		replace anoest = 17 if e6a_no_asiste == 14 & e6b_no_asiste == -88 & anoest ==. & e6c_completo == 2
		replace anoest = 12 + e6d_preg + e6d_postg + e6b_no_asiste if e6a_no_asiste == 15 & e6b_no_asiste>=1 & e6b_no_asiste<=6 & anoest ==. & e6d_preg>=0 & e6d_preg<. & e6d_postg>=0 & e6d_postg<.	 	/* Doctorado*/
		replace anoest = 14 + e6d_preg + e6b_no_asiste if e6a_no_asiste == 15 & e6b_no_asiste>=1 & e6b_no_asiste<=6 & anoest ==. & e6d_preg==-88 & e6d_postg>=0 & e6d_postg<.
		replace anoest = 19  + e6b_no_asiste if e6a_no_asiste == 15 & e6b_no_asiste>=1 & e6b_no_asiste<=6 & anoest ==. & e6d_preg>=0 & e6d_preg<. & e6d_postg==-88 // arrojaba valores negativos a002

		replace anoest = 19 + e6b_no_asiste if e6a_no_asiste == 15 & e6b_no_asiste>=1 & e6b_no_asiste<=6 & anoest ==. & e6d_preg== -88 & e6d_postg==-88
		replace anoest = 23 if e6a_no_asiste == 15 & e6b_no_asiste == -88 & anoest ==.	& e6c_completo ==1  
		replace anoest = 17 if e6a_no_asiste == 15 & e6b_no_asiste == -88 & anoest ==.	& e6c_completo ==2 


		/*VALIDACION*/
		quietly: count if anoest == .
		if r(N) {
			noi display in red _newline(1) ///
				"***ATENCION: Problema al crear ANOEST en " r(N) " observaciones."

			noi list edad e6a_asiste e6b_asiste e6a_no_asiste e6b_no_asiste ///
				if anoest == ., nolabel abbreviate(32)

			noi display in red _newline(1) "***ERROR: Proceso cancelado"
			exit 20006
		}



		/* INGRESOS*/

		noi display "Variables de ingreso "

		/*Sueldos y salarios*/

		noi display _col(10) "Variables de ingreso -> |" _continue
		local sys1 "y1    y3a   y3b   y3c   y3d   y3e   y3f   y4a   y4b   y4c   y4d   y5a   y5b   y5c   y5d   y5e   y5f   y5g   y5h   y5i   y5j   y5k   y5l   y6    y10   y18a y14b"
		local sys2 "y0101 y0301 y0302 y0303 y0304 y0305 y0306 y0401 y0402 y0403 y0404 y0501 y0502 y0503 y0504 y0505 y0506 y0507 y0508 y0509 y0510 y0511 y0512 y0601 y1001 yids aux01"

		local i = 1
		local n: word count `sys1'
		while `i' <= `n' {
			local var1 : word `i' of `sys1' 
			local var2 : word `i' of `sys2'
			gen `var2' = `var1' 
			replace `var2' = .z if `var1' == 0
			replace `var2' = .m if `var1' == -88 | `var1' ==-99
			local lab: variable label `var1'
			label variable `var2' "`lab'"
			local i = `i' + 1
		}

		/*VALIDACION*/

		foreach var in y0101 {

			noi display "`var' |" _continue
			if `validaciones' == 1 outsm `var', st("`stlist'") vars("folio id_persona_orig edad o10 condact ocupr categ o9a y2_dias y2_hrs") ifpre("o10 >= 35 & o10 < .") name("`dir0'\\Ing.xlsx")	//NOTA: Filtrar preserve por o10 >= 35
		}	
		noi  display ""

		foreach var in y0501 y0502 y0503 y0504 y0505 y0506 y0507 y0508 y0509 y0510 y0511 y0512 {

			noi display "`var' |" _continue
			if `validaciones' == 1 outsm `var', st("`stlist'") vars("folio orden edad condact ocupr categ o9a") name("`dir0'\\Ing.xlsx")
		}	

		noi  display ""

		/*Se eliminan valor completo de automoviles en y5d (y0504) (15 millones o más), acuerdo con MDS*/
		noi replace y0504 = . if y0504 >=15000000 & y0504 <.

		/* Sueldos y salarios ocupación principal*/


		local sysp1 "y0301 y0302 y0303 y0304 y0305 y0306"
		local sysp1p "y3ap y3bp y3cp y3dp y3ep y3fp"

		local sysp2 "y0401 y0402 y0403 y0404"


		local i = 1
		local n: word count `sysp1'
		while `i' <= `n' {
			local var1 : word `i' of `sysp1' 
			local var2 : word `i' of `sysp1p'

			replace `var1' = `var1' 					if `var2' == 1 & `var1' >0 & `var1'!=. & `var1'!=.m
			replace `var1' = max(round(`var1' / 2),1)	if `var2' == 2 & `var1' >0 & `var1'!=. & `var1'!=.m
			replace `var1' = max(round(`var1' / 3),1)	if `var2' == 3 & `var1' >0 & `var1'!=. & `var1'!=.m
			replace `var1' = max(round(`var1' / 4),1) 	if `var2' == 4 & `var1' >0 & `var1'!=. & `var1'!=.m
			replace `var1' = max(round(`var1' / 6),1) 	if `var2' == 5 & `var1' >0 & `var1'!=. & `var1'!=.m
			replace `var1' = max(round(`var1' / 12),1) 	if `var2' == 6 & `var1' >0 & `var1'!=. & `var1'!=.m
			replace `var1' = `var1'					 	if (`var2' == -88 | `var2' == -99 | `var2' == .) & `var1' >0
			local i = `i' + 1
		}


		foreach w of local sysp2 {
			replace `w' = max(round(`w'/12),1) if `w'>0 & `w'!= . & `w'!= .m & `w'!= .z
		}

		/*VALIDACION*/

		local sysp2p "y3a y3b y3c y3d y3e y3f"

		local i = 1
		local n: word count `sysp1'
		while `i' <= `n' {
			local var1 : word `i' of `sysp1' 
			local var2 : word `i' of `sysp1p'
			local var3 : word `i' of `sysp2p'

			noi display "`var1' |" _continue
			if `validaciones' == 1 outsm `var1', st("`stlist'") vars("folio id_persona_orig edad condact ocupr categ o9a `var2' `var3'") name("`dir0'\\Ing.xlsx")
			local i = `i' + 1
		}	

		local sysp2o "y4a y4b y4c y4d"

		local i = 1
		local n: word count `sysp2'
		while `i' <= `n' {
			local var1 : word `i' of `sysp2' 
			local var2 : word `i' of `sysp2o'

			noi display "`var' |" _continue
			if `validaciones' == 1 outsm `var1', st("`stlist'") vars("folio id_persona_orig edad condact ocupr categ o9a `var2'") name("`dir0'\\Ing.xlsx")
			local i = `i' + 1
		}	


		/* Sueldos y salarios ocupación secundaria*/

		/*VALIDACION*/
		* noi list folio y6 y10 if y6==y10 & y6!=. & y6!=0 & y6!=-88

		egen yosa = rowtotal(y0601 y1001) if inlist(o30,3,4,5,6,7,8),m

		/* Sueldos y salarios otros */

		replace yids = max(round(yids / 12),1) if yids > 0 & yids!= . & yids!= .m & yids!= .z

		gen yta1 = cond(inlist(categ, 3,4,5,6,7,8),aux01, .)

		/*VALIDACION*/
		foreach var in yosa yids yta1 {
			summ `var', d

			noi display "`var' |" _continue
			if `validaciones' == 1 outsm `var', st("`stlist'") vars("folio id_persona_orig edad condact ocupr categ o9a") name("`dir0'\\Ing.xlsx")
		}


		/*Ganancias*/


		local gan1 "y7    y8    y9    y17"
		local gan2 "y0701 y0801 y0901 yac2"

		local i = 1
		local n: word count `gan1'
		while `i' <= `n' {
			local var1 : word `i' of `gan1' 
			local var2 : word `i' of `gan2'
			gen `var2' = `var1' 
			replace `var2' = .z if `var1' == 0
			replace `var2' = .m if `var1' == -88 | `var1' == -99
			local lab: variable label `var1'
			label variable `var2' "`lab'"
			local i = `i' + 1
		}

		/*Se elimina registro anómalo (25,000,000) en y17 en acuerdo con MDS*/
		replace yac2 = . if yac2 == 25000000

		/*VALIDACION*/
		* noi list folio id_persona_orig y7 y9 if y7==y9 & y7!=. & y7!=0 & y7!=-88	

		/*Ganancias de la ocupacion principal*/

		replace y0901 = max(round(y0901 / 12),1) if y0901 >0 & y0901!= . & y0901!= .m & y0901!= .z

		/*VALIDACION*/
		foreach var in y0701 y0801 y0901 {
			if "`var'" == "y0901" {
				local var_o "y9"
			}
			else local var_o ""

			noi display "`var' |" _continue
			if `validaciones' == 1 outsm `var', st("`stlist'") vars("folio id_persona_orig edad condact ocupr categ o9a `var_o'") name("`dir0'\\Ing.xlsx")

		}

		/*Cambia ingresos del trabajo de no ocupados a y11*/

		local fnr1 "y11"
		local fnr2 "y1101"

		local i = 1
		local n: word count `fnr1'
		while `i' <= `n' {
			local var1 : word `i' of `fnr1' 
			local var2 : word `i' of `fnr2'
			gen `var2' = `var1' 
			replace `var2' = .z if `var1' == 0
			replace `var2' = .m if `var1' == -88
			local lab: variable label `var1'
			label variable `var2' "`lab'"
			local i = `i' + 1
		}

		/*REVISION DE INGRESOS DE LOS NO OCUPADOS, DISTINTOS DE Y11*/
		noi list edad condact categ y0701 y0801 y0901	///
			if (y0701>0 & y0701<. | y0801>0 & y0801<. | y0901>0 & y0901<.) & condact!=1


		egen y1101aux = rowtotal(y1101 y0701 y0801 y0901) if (categ<1 | categ>8) & y1101 == .,m
		replace y1101aux = y1101 if y1101>0 & y1101!=. & y1101!=.z & y1101!=.m
		drop y1101
		rename y1101aux y1101

		foreach var in y0701 y0801 y0901{
			replace `var' = . if condact!=1
		}

		/*VALIDACION*/
		*tabstat y1101, s(min p1 mean p50 p99 max)
		*noi list folio id_persona_orig edad condact categ y1101 if y1101 >0 & y1101<. & condact==1		//Validar si corresponden a familiares no remunerados

		/*Ganancias de la ocupacion secundaria*/

		egen yosi = rowtotal(y0601 y1001) if o30!=3 & o30!=4 & o30!=5 & o30!=6 & o30!=7 & o30!=8, m   


		/*Ganancias otras*/

		replace yac2 = max(round(yac2 / 12),1) if yac2 > 0 & yac2!= . & yac2!= .m & yac2!= .z

		gen yta2 = cond(categ!=3 & categ!=4 & categ!=5 & categ!=6 & categ!=7 & categ!=8,aux01, .)


		*VALIDACION*/
		foreach var in yosi yac2 yta2 {

			noi display "`var' |" _continue
			if `validaciones' == 1 outsm `var', st("`stlist'") vars("folio id_persona_orig edad condact ocupr categ o9a") name("`dir0'\\Ing.xlsx")
		}

		drop aux01 y0601 y1001



		/*Ingreso de capital*/

		local ycap1 "y12a y12b y15a y15b y15c y16a y16b"
		local ycap2 "yre1 yama yah1 yah2 yrut yre2 yre3"


		local i = 1
		local n: word count `ycap1'
		while `i' <= `n' {
			local var1 : word `i' of `ycap1' 
			local var2 : word `i' of `ycap2'
			gen `var2' = `var1' 
			replace `var2' = .z if `var1' == 0
			replace `var2' = .m if `var1' == -88
			local lab: variable label `var1'
			label variable `var2' "`lab'"
			local i = `i' + 1
		}

		foreach v of var yah1 yah2 yrut yre2 yre3 {
			replace `v' = max(round(`v' /12),1) if `v' >0 & `v'!=. & `v'!=.m & `v'!=.z
		}

		/*VALIDACION*/
		local i = 1
		local n: word count `ycap2'
		while `i' <= `n' {
			local var1 : word `i' of `ycap1' 
			local var2 : word `i' of `ycap2'

			if `validaciones' == 1 outsm `var2', st("`stlist'") vars("folio edad condact ocupr categ o9a `var1'") name("`dir0'\\Ing.xlsx")
			local i = `i' + 1
		}	

		/*Ingreso por jubilaciones y pensiones*/


		local yjub1 "y28_2b1 y28_2b2 y28_2c1 y28_2c2 y28_2c y28_2e1  y28_2e2  y28_2f y28_2g1  y28_2g2  y28_2g 	y28_2h y28_2i1   y28_2i2  y28_2i y28_2j"		
		local yjub2 "y280201 y280202 y280301 y280302 y2803  yinv0101 yinv0102 yinv02 ymon0101 ymon0102 ymon02   yorf   yesp0101  yesp0102 yesp   yotp"

		local i = 1
		local n: word count `yjub1'
		while `i' <= `n' {
			local var1 : word `i' of `yjub1' 
			local var2 : word `i' of `yjub2'
			gen `var2' = `var1' 
			replace `var2' = .z if `var1' == 0
			replace `var2' = .m if `var1' == -88 
			local lab: variable label `var1'
			label variable `var2' "`lab'"
			local i = `i' + 1
		}

		gen y2804 = cond(y28_1d == 1 & edad >= 18 & edad <= 64, 193935, .)		/*Pensión básica solidaria de invalidez*/
		replace y2804 = .m if y28_1d == -88

		gen y280101 = cond(y28_1c1 == 1 & y28_1c2 == 1 & edad>=65, 193917, .)		/*Pensión garantizada universal(antes pensión básica solidaria de vejez)*/
		replace y280101 = .m if y28_1c1 == -88


		/* Se reemplazan casos que no corresponden a otras pensiones de acuerdo al especifique*/
		noi replace yotp = . if strpos(y28j_esp, "divorcio")

		/*VALIDACIONES*/

		foreach var of local yjub2 {

			noi display "`var' |" _continue
			if `validaciones' == 1 outsm `var', st("`stlist'") vars("folio id_persona_orig edad condact ") ifsum("condact == 15") name("`dir0'\\Ing.xlsx")		//NOTA: Percentiles si condact == 15 (jubilados)
		}


		/*Valida PGU debe ser única entre las diversas preguntas*/
		gen pgu1 = (y280101>0 & y280101<.)			/*Solo PGU*/
		gen pgu2 = (y280302>0 & y280302<.)			/*Complemento PGU pensión de vejez*/
		gen pgu3 = (ymon0102>0 & ymon0102<.)		/*Complemento PGU montepío*/
		gen pgu4 = (yesp0102>0 & yesp0102<.)		/*Complemento PGU leyes especiales*/
		gen pgu = pgu1 + pgu2 + pgu3 + pgu4

		quietly: count if pgu>1
		if r(N)  {
			noi display in red _newline(1) ///
				"***ATENCION: Problema con repetición de PGU en " r(N) " observaciones."

			noi list y28_1c1 y28_1c2 y280101 y280301 y280302 y28_1g1 ymon0101 ymon0102 y281i1 yesp0101 yesp0102///
				if pgu>1, nolabel abbreviate(32)

			display in red _newline(1) "***ERROR: Proceso cancelado"
			exit 20007
		}
		drop pgu*

		/*Valida pensión de vejez recibida por una sola fuente*/
		gen pv1 = (y280101>0 & y280101<.)									/*PGU vejez*/
		gen pv2 = ((y280201>0 & y280201<.) | (y280202>0 & y280202<.))		/*Vejez con APS*/
		gen pv3 = ((y280301>0 & y280301<.) | (y280302>0 & y280302<.))		/*Vejez con PGU*/
		gen pv4 = (y2803>0 & y2803<.)										/*Vejez*/
		gen pv = pv1 + pv2 + pv3 + pv4

		quietly: count if pv>1
		if r(N)  {
			noi display in red _newline(1)		///
				"***ATENCION: Duplicación fuentes de pensión de vejez en " r(N) " observaciones."

			noi list y28_1c1 y28_1c2 y280101 y280301 y280302 y28_1b y280201 y280202 y28_1c y2803		///
				if pv>1, nolabel abbreviate(32)

			display in red _newline(1) "***ERROR: Proceso cancelado"
			exit 20008
		}


		drop pv*

		/*Ingreso por otras transferencias*/


		local yot1 "y13a y13b y13c y14c y18b y18c y18d y23a  y24   y25amonto  y25bmonto  y25e  y25f  y27"	
		local yot2 "ymes yfa1 yfa2 ydes ydon ydim yotr y2301 y2401 y2501 	  y2502      y2505 y2506 y2701"


		local i = 1
		local n: word count `yot1'
		while `i' <= `n' {
			local var1 : word `i' of `yot1' 
			local var2 : word `i' of `yot2'
			gen `var2' = `var1' 
			replace `var2' = .z if `var1' == 0
			replace `var2' = .m if `var1' == -88 
			local lab: variable label `var1'
			label variable `var2' "`lab'"
			local i = `i' + 1
		}

		/*VALIDACIONES*/
		foreach var in ymes yfa1 yfa2 ydes y2301 {

			noi display "`var' |" _continue
			if `validaciones' == 1 outsm `var', st("`stlist'") vars("folio orden edad condact ") name("`dir0'\\Ing.xlsx")

		}

		list folio orden y18d_esp if yotr>0 & yotr<.

		/*Se eliminan los casos que no corresponden a ingresos corrientes de yotr*/
		gen y18d_esp2 = strlower(y18d_esp)

		gen aux18esp = 0
		replace aux18esp = 1 if strpos(y18d_esp2, "herencia")
		replace aux18esp = 1 if strpos(y18d_esp2, "préstamo")
		replace aux18esp = 1 if strpos(y18d_esp2, "vehículo")
		replace aux18esp = 1 if strpos(y18d_esp2, "auto")
		replace aux18esp = 1 if strpos(y18d_esp2, "moto")
		replace aux18esp = 1 if strpos(y18d_esp2, "propiedad")
		replace aux18esp = 1 if strpos(y18d_esp2, "casa")
		replace aux18esp = 1 if strpos(y18d_esp2, "terreno")
		replace aux18esp = 1 if strpos(y18d_esp2, "parcela")
		replace aux18esp = 1 if strpos(y18d_esp2, "oficina")
		replace aux18esp = 1 if strpos(y18d_esp2, "animal")
		replace aux18esp = 1 if strpos(y18d_esp2, "cordero")
		replace aux18esp = 1 if strpos(y18d_esp2, "ternero")
		replace aux18esp = 1 if strpos(y18d_esp2, "vacuno")
		replace aux18esp = 1 if strpos(y18d_esp2, "buey")
		replace aux18esp = 1 if strpos(y18d_esp2, "caballo")
		replace aux18esp = 1 if strpos(y18d_esp2, "seguro")
		replace aux18esp = 1 if strpos(y18d_esp2, "falleci")
		replace aux18esp = 1 if strpos(y18d_esp2, "milenio")
		replace aux18esp = 1 if strpos(y18d_esp2, "patente")
		replace aux18esp = 1 if strpos(y18d_esp2, "ahorro")
		replace aux18esp = 1 if strpos(y18d_esp2, "fondecyt")
		replace aux18esp = 1 if strpos(y18d_esp2, "sercotec")
		replace aux18esp = 1 if strpos(y18d_esp2, "azar")
		replace aux18esp = 1 if strpos(y18d_esp2, "distintos")
		replace aux18esp = 1 if strpos(y18d_esp2, "sobrevivir")
		replace aux18esp = 1 if y18d_esp2 == "venta de derechos sociales"
		replace aux18esp = 1 if y18d_esp2 == "ingreso ayuda a pyme"
		replace aux18esp = 1 if y18d_esp2 == "venta de uva"
		replace aux18esp = 1 if y18d_esp2 == "venta de mineral"
		replace aux18esp = 1 if y18d_esp2 == "venta de cosas personales"
		replace aux18esp = 1 if y18d_esp2 == "venta de joyas"
		replace aux18esp = 1 if y18d_esp2 == "venta"
		replace aux18esp = 1 if y18d_esp2 == "extra"
		replace aux18esp = 1 if y18d_esp2 == "pyme"
		replace aux18esp = 1 if y18d_esp2 == "avita"
		replace aux18esp = 1 if y18d_esp2 == "bice vida"
		replace aux18esp = 1 if y18d_esp2 == "ingreso familiar de emergencia (ife)"

		replace aux18esp = 0 if strpos(y18d_esp2, "arriendo")
		replace aux18esp = 0 if strpos(y18d_esp2, "objetos")
		replace aux18esp = 0 if strpos(y18d_esp2, "libros")
		replace aux18esp = 0 if y18d_esp2 == "devolución prima de seguro"
		replace aux18esp = 0 if y18d_esp2 == "hizo pololo en cement radier en una casa"
		replace aux18esp = 0 if y18d_esp2 == "cuenta de ahorro premium banco estado"
		replace aux18esp = 0 if y18d_esp2 == "alquiler de vehículos"
		replace aux18esp = 0 if y18d_esp2 == "retiros de seguros"
		replace aux18esp = 0 if y18d_esp2 == "carpintería reparación de casas"
		replace aux18esp = 0 if y18d_esp2 == "administración de propiedades"
		replace aux18esp = 0 if y18d_esp2 == "docente en otra casa de estudios"
		replace aux18esp = 0 if y18d_esp2 == "vendió una propiedad y su comisión fue ganancia"
		replace aux18esp = 0 if y18d_esp2 == "seguro del marido"

		replace yotr = . if aux18esp == 1


		preserve 

		gen N = 1
		collapse (sum) N, by(y18d_esp2 aux18esp )
		export excel using "`dir0'\\yotr strpos.xlsx", sheet("y18d_esp") sheetmodify firstrow(variables) nolabel keepcellfmt
		restore 

		drop y18d_esp2 aux18esp

		gen y2302 = cond(edad<=6 & y23b == 1, 8000, .)
		replace y2302 = .m if y23b == -88

		gen y2303 = cond(edad>=6 & edad <=19 & y23c == 1, 8000, .)
		replace y2303 = .m if y23c == -88

		gen y2503 = 176998 if y25c == 1 & edad>=60 
		replace y2503 = .m if y25c == -88

		gen y2504 = 70336 if y25d ==1 & edad >=60
		replace y2504 = .m if y25d == -88


		replace y2701 = max(round(y2701/12),1) if y27_preg == 2 & y2701!=. & y2701!= .m  /*Bonos anuales*/


		/*Revisar especifique de y27 (otros subsidios del estado)*/
		// 416 casos "subsidio a la calefacción (ex bono leña)"

		/*Subsido a la calefacción es solo en región de Aysén y con un máximo de 100.000 por hogar (MDS).*/
		tab region if (y27_preg == 1 | y27_preg == 2) & y27_esp== "subsidio a la calefacción (ex bono leña)" //4 casos de 416 fuera de Aysen
		replace y2701 = . if y27_esp== "subsidio a la calefacción (ex bono leña)" & region != 11

		bysort id_hogar: gen aux27 = (y27_esp== "subsidio a la calefacción (ex bono leña)")
		tab aux27,m
		tab y2701 if aux27==1 	
		drop aux27
		/*Existen 3 casos en que se declara el subsidio como mensual, siendo anual. Se corrige el monto mensualizandolo*/
		replace y2701 = max(round(y2701/12),1) if y2701 == 100000 & y27_preg == 1 & y27_esp== "subsidio a la calefacción (ex bono leña)"

		/*Revisión de otros casos de y27*/
		list id_hogar id_persona_orig edad y27 y27_esp if (y27_preg == 1 | y27_preg == 2) & y27_esp!= "subsidio a la calefacción (ex bono leña)" 

		/*Se eliminan los casos que no corresponden de y2701*/
		gen y27_esp2 = strlower(y27_esp)

		gen aux27esp = 0
		replace aux27esp = 1 if strpos(y27_esp2, "indap")>0
		replace aux27esp = 1 if strpos(y27_esp2, "aguinaldo")>0 & condact!=15 & condact!=9 /*Aguinaldos de los jubilados y enfermos o discapacitados se mantienen*/
		replace aux27esp = 1 if strpos(y27_esp2, "pyme")>0
		replace aux27esp = 1 if strpos(y27_esp2, "pdti")>0
		replace aux27esp = 1 if strpos(y27_esp2, "agrícola")>0
		replace aux27esp = 1 if strpos(y27_esp2, "fosis")>0
		replace aux27esp = 1 if strpos(y27_esp2, "sii")>0
		replace aux27esp = 1 if strpos(y27_esp2, "cense")>0
		replace aux27esp = 1 if strpos(y27_esp2, "caja")>0		
		replace aux27esp = 1 if strpos(y27_esp2, "canasta")>0
		replace aux27esp = 1 if strpos(y27_esp2, "microempresa")>0
		replace aux27esp = 1 if strpos(y27_esp2, "prodesal")>0
		replace aux27esp = 1 if strpos(y27_esp2, "provesal")>0
		replace aux27esp = 1 if strpos(y27_esp2, "préstamo")>0
		replace aux27esp = 1 if strpos(y27_esp2, "ganado")>0
		replace aux27esp = 1 if strpos(y27_esp2, "navidad")>0 & condact!=15 & condact!=9 /*Aguinaldos de los jubilados y enfermos o discapacitados se mantienen*/
		replace aux27esp = 1 if strpos(y27_esp2, "retención")>0
		replace aux27esp = 1 if strpos(y27_esp2, "gas ")>0
		replace aux27esp = 1 if strpos(y27_esp2, "gas")>0
		replace aux27esp = 1 if strpos(y27_esp2, "bencina")>0
		replace aux27esp = 1 if strpos(y27_esp2, "hijo")>0
		replace aux27esp = 1 if strpos(y27_esp2, "metro")>0
		replace aux27esp = 1 if y27_esp2 == "gratuidad escolar por sus 3 hijos son alumnos prioritarios"
		replace aux27esp = 1 if y27_esp2 == "gift card para alimentos"
		replace aux27esp = 1 if y27_esp2 == "bono covid"
		replace aux27esp = 1 if y27_esp2 == "bono ferias libres"
		replace aux27esp = 1 if y27_esp2 == "bono para alimentación de abejas"
		replace aux27esp = 1 if y27_esp2 == "subsidio de vivienda"
		replace aux27esp = 1 if y27_esp2 == "subsidio tarifa locomoción colectiva"
		replace aux27esp = 1 if y27_esp2 == "bonos incluidos en la jubilación"
		replace aux27esp = 1 if y27_esp2 == "bonos y aguinaldos junto a la jubilación"		
		replace aux27esp = 1 if y27_esp2 == "rebaja en contribuciones por edad y antigüedad de morador"
		replace aux27esp = 1 if y27_esp2 == "universal"

		replace y2701 = . if aux27esp == 1

		preserve 

		gen N = 1
		collapse (sum) N, by(y27_esp2 aux27esp )
		export excel using "`dir0'\\yotr strpos.xlsx", sheet("y27_esp") sheetmodify firstrow(variables) nolabel keepcellfmt
		restore 

		drop y27_esp2 aux27esp


		egen y22total = rowtotal(y22amonto y22bmonto y22cmonto y22dmonto)
		replace y22total = -88 if y22total == 0 & y22 == -88
		replace y22total = .  if y22_preg == 2 | y22_preg == .| y22_preg == -88

		local yot3 "y20amonto y20bmonto y20cmonto y20dmonto y20emonto y22amonto y22bmonto y22cmonto y22dmonto" 		
		local yot4 "y2001 	  y2002 	y2003 	  y2004 	y2005 	  y2201		y2202	  y2203     y2204"

		local i = 1
		local n: word count `yot3'
		while `i' <= `n' {
			local var1 : word `i' of `yot3' 
			local var2 : word `i' of `yot4'
			gen `var2' = `var1' 
			replace `var2' = .z if `var1' == 0
			replace `var2' = .m if `var1' == -88 
			local lab: variable label `var1'
			label variable `var2' "`lab'"
			local i = `i' + 1
		}

		drop y22total

		foreach v of var ydon ydim yotr y2501 y2502 y2503 y2504 {
			replace `v' = max(round(`v'/12),1) if `v'>0 & `v'!=. & `v'!=.m & `v'!=.z
		}
		replace y2505 = max(round(y2505/12),1) if y2505>0 & y2505!=. & y2505!=.m & y2505!=.z & y25ep == 2  /*frecuencia anual*/
		replace y2506 = max(round(y2506/12),1) if y2506>0 & y2506!=. & y2506!=.m & y2506!=.z & y25fp == 2  /*frecuencia anual*/


		/*VALIDACIONES*/
		foreach var in ydon ydim yotr y2501 y2502 y2503 y2504 y2505 y2506 y2701 y2302 y2303 y2503 y2504 y2505 y2506 y2701 {
			noi display "`var' |" _continue
			if `validaciones' == 1 outsm `var', st("`stlist'") vars("folio id_persona_orig sexo edad ") name("`dir0'\\Ing.xlsx")
		}


		foreach var of local yot4 {
			noi display "`var' |" _continue
			if `validaciones' == 1 outsm `var', st("`stlist'") vars("folio id_persona_orig sexo edad ") name("`dir0'\\Ing.xlsx")
		}


		/*Transferencias del estado*/

		tab y19t y19n,m

		gen yfam = y19n * 16418		if y19t == 1 & y19n>0 & y19n<99
		replace yfam = y19n * 10075 	if y19t == 2 & y19n>0 & y19n<99
		replace yfam = y19n * 3184 	if y19t == 3 & y19n>0 & y19n<99
		replace yfam = .m if y19t == -88 | ((y19n<=0 | y19n>=99) & inlist(y19t,1,2,3))


		/*Valida edad asign fam*/
		quietly: count if yfam>0 & yfam<. & edad <12
		if r(N)  {
			noi display in red _newline(1) ///
				"***ATENCION: Edad menor a 12 en " r(N) " observaciones de recepción de asig fam."

			noi list edad yfam y19 y19n y19t ///
				if yfam>0 & yfam<. & edad <12, nolabel abbreviate(32)

			display in red _newline(1) "***ERROR: Proceso cancelado"
			exit 20010
		}


		/*Valida edad y sexo en requisitos SUF*/
		gen suf1 = 1 if y20a ==1 & edad>19
		gen suf2 = 1 if (y20b == 1 & sexo!= 2) | (y20b == 1 & (edad<=12 | edad>=59))
		gen suf3 = 1 if y20c == 1 & edad<12 
		gen suf4 = 1 if y20e == 1 & edad>19	

		gen cond_SUF = suf1 + suf2 + suf3 + suf4	
		quietly: count if cond_SUF >= 1 & cond_SUF<.
		if r(N)  {
			noi display in red _newline(1) ///
				"***ATENCION: Condiciones para SUF no se cumplen en " r(N) " observaciones"

			noi list edad sexo y20a y2001 y20b y2002 y20c y2003 y20d y2004 y20e y2005  ///
				if cond_SUF >= 1 & cond_SUF<., nolabel abbreviate(32)

			display in red _newline(1) "***ERROR: Proceso cancelado"
			exit 20011
		}		

		drop suf* cond_SUF

		/* Nuevas transferencias del estado 2020 - 2022*/
		/*2022:Se incluye: y21_canasta (ingresos por Aporte para la Canasta de Alimentos), y25h (IFE laboral) */
		/*2022:Se eliminan: y26a (bono ayuda familiar), y26b (bono emergencia covid), y26c (bono clase media (no se sumaba)),  */

		local yot5 "y25g  y25hp  y25h" 		
		local yot6 "y2507 y2508p y2508"

		local i = 1
		local n: word count `yot5'
		while `i' <= `n' {
			local var1 : word `i' of `yot5' 
			local var2 : word `i' of `yot6'
			gen `var2' = `var1' 
			replace `var2' = .z if `var1' == 0
			replace `var2' = .m if `var1' == -88 
			local lab: variable label `var1'
			label variable `var2' "`lab'"
			local i = `i' + 1
		}

		/*APORTE CANASTA DE ALIMENTOS:Suma los aportes que se agregan al SUF (y20a a y20d) o a la asignación familiar (y19) o los pagados solos (y21_canasta)*/

		/*Valida que las personas que hayan declarado en y21 no reciban SUF o asignación familiar*/
		gen recibe_SUF = ((y2001>0 & y2001<.)|(y2002>0 & y2002<.)|(y2003>0 & y2003<.)|(y2004>0 & y2004<.))
		gen recibe_AF = (yfam>0 & yfam<.)

		quietly: count if (recibe_SUF == 1 | recibe_AF == 1) & y21_canasta == 1
		if r(N)  {
			noi display in red _newline(1) ///
				"***ATENCION: Canasta duplicada en " r(N) " observaciones."

			noi list y20a y2001 y20b y2002 y20c y2003 y20d y2004 y19 yfam y21_canasta ///
				if (recibe_SUF == 1 | recibe_AF == 1) & y21_canasta == 1, nolabel abbreviate(32)

			display in red _newline(1) "***ERROR: Proceso cancelado"
			exit 20012
		}	

		/*Se reemplaza por y21_canasta == 2 si recibe_SUF_AF == 1*/
		replace y21_canasta = 2 if (recibe_SUF == 1 | recibe_AF == 1) & y21_canasta ==1


		/*Se genera variable ingreso por canasta de las tres fuentes de acuerdo al mes*/

		gen y2101 = 0
		replace y2101 = 10803 if recibe_SUF == 1 & mes == "11"		/*octubre22 mes del ingreso, mes de encuesta noviembre */
		replace y2101 = 11318 if recibe_SUF == 1 & mes == "12"		/*noviembre22 mes del ingreso, mes de encuesta diciembre*/
		replace y2101 = 11408 if recibe_SUF == 1 & mes == "01"		/*diciembre22 mes del ingreso, mes de encuesta enero 2023*/
		replace y2101 = 11408 if recibe_SUF == 1 & mes == "02"		/*diciembre22 mes del ingreso, mes de encuesta febrero 2023*/
		replace y2101 = 10803* y19n if recibe_AF == 1 & mes == "11"	& y19n>=1 & y19n<=10	
		replace y2101 = 11318* y19n if recibe_AF == 1 & mes == "12"	& y19n>=1 & y19n<=10	
		replace y2101 = 11408* y19n if recibe_AF == 1 & mes == "01"	& y19n>=1 & y19n<=10	
		replace y2101 = 11408* y19n if recibe_AF == 1 & mes == "02"	& y19n>=1 & y19n<=10		
		replace y2101 = 10803 if y21_canasta == 1 & mes == "11"
		replace y2101 = 11318 if y21_canasta == 1 & mes == "12"
		replace y2101 = 11408 if y21_canasta == 1 & mes == "01"
		replace y2101 = 11408 if y21_canasta == 1 & mes == "02"
		replace y2101 = .m if y2101 == 0 & y21_canasta == -88
		replace y2101 = . if y2101 == 0

		drop recibe_* 


		/*IFE*/

		/*VALIDACION*/
		/* Se revisan casos en que la suma del número de integrantes totales declarados como receptores de IFE es mayor a persindo*/

		gen y26d_integrantes_i = y26d_integrantes
		replace y26d_integrantes_i = 0 if inlist(y26d_integrantes_i,.,-88)


		/*Si se cuenta con el número de integrantes, se asigna el valor por tabla, si no, se toma la pregunta yd_monto, si esta es missing o -88, IFE queda en missing*/

		tab parentco y26d_hog
		tab y26d_hog y26d_preg
		tabstat y26d_monto, s(min p1 mean p50 p99 max)

		/*Se acota el monto al monto máximo recibido por 10 o más integrantes para ser utilizado posteriormente en la construcción de y2604*/
		gen y26d_monto_i = y26d_monto
		replace y26d_monto_i = 887000 if y26d_monto_i > 887000 & y26d_monto_i<.

		/*Dado el número alto de reportados como beneficiarios, los integrantes no se imputarán por fila sino que se agregan a nivel hogar y se trunca en el número de personas del hogar*/

		gen p = 1
		bysort id_hogar: egen pers_hog = sum(p) if nucleo!=0

		bysort id_hogar: egen y26d_inth = sum(y26d_integrantes_i)
		replace y26d_inth = pers_hog if y26d_inth > pers_hog
		replace y26d_inth = 0 if parentco!=1

		gen y2604 = 0
		replace y2604 = 177000 if y26d_preg == 1 & y26d_inth == 1
		replace y2604 = 287000 if y26d_preg == 1 & y26d_inth == 2
		replace y2604 = 400000 if y26d_preg == 1 & y26d_inth == 3
		replace y2604 = 500000 if y26d_preg == 1 & y26d_inth == 4
		replace y2604 = 546000 if y26d_preg == 1 & y26d_inth == 5
		replace y2604 = 620000 if y26d_preg == 1 & y26d_inth == 6
		replace y2604 = 691000 if y26d_preg == 1 & y26d_inth == 7
		replace y2604 = 759000 if y26d_preg == 1 & y26d_inth == 8
		replace y2604 = 824000 if y26d_preg == 1 & y26d_inth == 9
		replace y2604 = 887000 if y26d_preg == 1 & y26d_inth >= 10
		replace y2604 = y26d_monto_i if y26d_preg == 1 & y26d_integrantes == -88 
		replace y2604 = .m if y26d_hog == -88
		replace y2604 = . if y2604 == 0 | y2604 == -88

		drop y26d_monto_i y26d_integrantes_i p pers_hog y26d_inth


		/* IFE LABORAL*/

		/*Validacion de edad - mayores de 18*/
		quietly: count if y25h_preg == 1 & edad <18
		if r(N)  {
			noi display in red _newline(1) ///
				"***ATENCION: Edad menor a 18 en " r(N) " observaciones."

			noi list edad y25h_preg y25hp y2508p y25h y2508 ///
				if y25h_preg == 1 & edad <18, nolabel abbreviate(32)

			display in red _newline(1) "***ERROR: Proceso cancelado"
			exit 20013
		}	

		/*Identificación de casos IFE laboral*/

		gen caso_ifelab = 1 if y25h_preg == 1 & y2508p >= 1 & y2508p <= 3 & y2508 >0 & y2508 <.																/*1 Declara recibir ife laboral, el número de pagos y el monto. Se trunca el máximo*/
		replace caso_ifelab = 2 if y25h_preg == 1 & y2508p >= 1 & y2508p <= 3 & (y2508==. | y2508==.m | y2508==.z)											/*2 Declara recibir ife laboral y número de pagos, no declara el monto. SE DEJA COMO VALOR MISSING (MDS)*/
		replace caso_ifelab = 3 if y25h_preg == 1 &  y2508p == .m & y2508 >0 & y2508 <.																		/*3 Declara recibir ife laboral y monto, no declara número de pagos. No se puede validar el máximo*/
		replace caso_ifelab = 4 if y25h_preg == 1 &  y2508p == .m & ( y2508==.| y2508==.m | y2508==.z)														/*4 Declara recibir ife laboral pero no declara ni número ni pagos ni monto. SE DEJA COMO VALOR MISSING (MDS)*/


		/*Se generan máximos a a pagar de acuerdo a lo enviado por MDS. Existen dos tramos de valores máximos, hasta junio de 2022 y desde julio 2022. Se dejan los máximos pagados por tramo etareo y sexo de ambos tramos*/

		gen max_ifelab =   0
		replace max_ifelab = y2508p * 200000 if y2508p >= 1 & y2508p <= 3 & sexo == 1 & edad > 24 & edad < 55	

		/*Listado de casos: hombres, entre 24 y 55, con montos mayores al máximo, para evaluación por el MDS de caso de discapacidad*/
		noi di "Listado de casos: hombres, entre 24 y 55, con montos mayores al máximo para sexo y tramo etario"
		noi list folio id_persona_orig sexo edad y2508p y2508 max_ifelab caso_ifelab if y2508p >= 1 & y2508p <= 3 & sexo == 1 & edad > 24 & edad <55 & y2508 > max_ifelab & caso_ifelab==1

		replace max_ifelab = y2508p * 300000 if y2508p >= 1 & y2508p <= 3 & sexo ==1 & edad >=18 & edad <=24			
		replace max_ifelab = y2508p * 300000 if y2508 >=1 & y2508p <=3 & sexo == 2


		/*Truncamiento para IFE laboral*/
		replace y2508 = max_ifelab if caso_ifelab == 1 & y2508 > max_ifelab & y2508<.

		drop caso_ifelab max_ifelab


		/*SUBSIDIO PROTEGE*/

		/*Validacion de edad - menor o igual a 6*/
		quietly: count if y25i_preg == 1 & edad > 6
		if r(N)  {
			noi display in red _newline(1) ///
				"***ATENCION: Edad mayor a 6 en " r(N) " observaciones."

			noi list edad y25i_preg y25ip  ///
				if y25i_preg == 1 & edad > 6, nolabel abbreviate(32)

			display in red _newline(1) "***ERROR: Proceso cancelado"
			exit 20014
		}	

		/*Validacion de edad - número de pagos*/
		quietly: count if y25i_preg == 1 & y25ip == 6 &  (edad>3 & edad<=6)
		if r(N)  {
			noi display in red _newline(1) ///
				"***ATENCION: 6 pagos subsidio PROTEGE en edades no correspondientes para " r(N) " observaciones."

			noi list folio orden edad y25i_preg y25ip  y25imonto ///
				if y25i_preg == 1 &  y25ip == 6 & edad>3 & edad<=6, nolabel abbreviate(32)

			display in red _newline(1) "***ERROR: Proceso cancelado"
			*exit 20015
		}	
		noi display "A"

		/* Se pone límite en 3 pagos para menores con edad igual a 4, los casos con 2 años puede ser valor válido (MDS)*/

		gen y2509 = y25imonto  
		replace y2509 = 600000 if y25ip == 6 & edad == 4
		replace y2509 = .m if y25ip == -88

		/*BONO CHILE APOYA DE INVIERNO*/

		/*Validacion de edad - mayor o igual a 12*/
		quietly: count if y25j_preg == 1 & edad <12
		if r(N)  {
			noi display in red _newline(1) ///
				"***ATENCION: Edad menor a 12 en " r(N) " observaciones."

			noi list edad y25j_preg y25j  ///
				if y25j_preg == 1 & edad <12, nolabel abbreviate(32)

			display in red _newline(1) "***ERROR: Proceso cancelado"
			*exit 20016
		}

		noi display "B"
		gen y2510 = 0
		replace y2510 = 120000 * y25j if y25j_preg == 1 & y25j>0 & y25j<.
		replace y2510 = 120000 if y25j_preg == 1 & y25j == -88	// Si no conoce el número de causantes se asume solo uno
		replace y2510 = . if y25j_preg !=1 & y25j==.
		
		noi display "B1"

		/*Mensualiza monto de transferencias anuales (o agregado anual)*/

		foreach v of var y2508 y2509 y2510 y2604 {		
			replace `v' = max(round(`v'/12),1) if `v'>0 & `v'!=. & `v'!=.m & `v'!=.z
		}

		noi display "B2"

		/*VALIDACION*/
		foreach var of var y2507 y2508 y2509 y2510 y2604 {

			noi display "`var' |" _continue
			if `validaciones' == 1 outsm `var', st("`stlist'") vars("folio id_persona_orig sexo edad ") name("`dir0'\\Ing.xlsx")
		} 

		noi display "C"

		/*Otros ingresos*/

		/*Revisa pregunta de recibió con monto*/
		gen aux_y14a = (y14a>0 & y14a<.)
		tab aux_y14a y14a_preg
		drop aux_y14a

		gen ytro = y14a if y14a_preg == 1
		replace ytro = .z if y14a == 0
		replace ytro = .m if y14a == -88

		noi display "D"

		/*Se calcula agregados de Ingreso */

		egen yaut = rowtotal(y0101 y0301 y0302 y0303 y0304 y0305 y0306 y0401 y0402 y0403 y0404 y0501 y0502 y0503 y0504 y0505 /*
			*/ y0506 y0507 y0508 y0509 y0510 y0511 y0512 yosa ytro yta1 y0701 y0801 y0901 yosi yta2 yrut yac2 ydes yids /*
		*/ yotr y280201 y280301 y2803 yinv0101 yinv02 ymon0101 ymon02 yorf yotp yre1 yre2 yre3 yama yah1 yah2 ydon ymes yfa1 yfa2 y1101 ydim),m

		egen ysub1 = rowtotal(yfam y2001 y2002 y2003 y2004 y2005 y2201 y2202 y2203 y2204 y2301 y2302 y2303 y2401 /*
		*/y2501 y2502 y2503 y2504 y2505 y2506 y2701 y280101 y280202 y280302 yinv0102 ymon0102 y2804 yesp0101 yesp0102 yesp),m

		egen ysub2 = rowtotal( y2101 y2507 y2508 y2509 y2510 y2604)

		egen ysub = rowtotal(ysub1 ysub2)

		egen ytot = rowtotal(yaut ysub1 ysub2),m

		noi save "`dir1'\\ca22dn02.dta", replace

	}

	**************************************************************************************************
	***** "Creación de DB03: generación de variables sociodemográficas y de ingreso nivel hogar" ***** 
	**************************************************************************************************

	if `part3' == 1 {

		noi display "Parte 3"
		use "`dir1'\\ca22dn02", clear


		/*Se generan variables nivel hogar*/

		gen pers = 1

		gen persindo = 	cond(nucleo!= 0,1,0)		/*personas en el hogar sin considerar servicio doméstico(miembros del hogar)*/
		gen ncony = 	cond(parentco == 2, 1, 0)
		gen nhijosam = 	cond(parentco == 3, 1, 0)
		gen nhijossj = 	cond(parentco == 4, 1, 0)
		gen nhijossc = 	cond(parentco == 5, 1, 0)
		gen npadres = 	cond(parentco == 6, 1, 0)
		gen nsuegros =  cond(parentco == 7, 1, 0)
		gen nyerno =	cond(parentco == 8, 1, 0)
		gen nnieto =	cond(parentco == 9, 1, 0)
		gen nherman =	cond(parentco == 10, 1, 0)
		gen ncunados = 	cond(parentco == 11, 1, 0)
		gen notrop =	cond(parentco == 12, 1, 0)
		gen notronp =	cond(parentco == 13, 1, 0)
		gen dom =		cond(nucleo == 0, 1, 0)
		gen nocup = 	cond(condact == 1 & nucleo!= 0,1,0)
		gen ndesocup =	cond((condact == 2 | condact == 3) & nucleo!= 0,1,0)

		gen nninos04 = cond(nucleo!= 0 & edad <=4, 1, 0)
		gen np12ym =   cond(nucleo!= 0 & edad >=12, 1, 0)
		gen np15ym =   cond(nucleo!= 0 & edad >=15, 1, 0)
		gen np25ym =   cond(nucleo!= 0 & edad >=25, 1, 0)
		gen estsum15 = anoest if np15ym == 1 & anoest>0 & anoest <99
		gen estsum25 = anoest if np25ym == 1 & anoest>0 & anoest <99



		/*Agregados de ingreso nivel hogar*/

		local agreing "y0101 y0301 y0302 y0303 y0304 y0305 y0306 y0401 y0402 y0403 y0404 y0501 y0502 y0503 y0504 y0505 y0506 y0507 y0508 y0509 y0510 "
		local agreing "`agreing' y0511  y0512 yosa ytro yta1 y0701 y0801 y0901 yosi yta2 yrut yac2 ydes yids yotr y280201 y280301 y2803 yinv0101 yinv02  "
		local agreing "`agreing' ymon0101 ymon0102 ymon02 yotp yre1 yre2 yre3 yama yah1 yah2 ydon ymes yfa1 yfa2 y1101 ydim yfam y2001 y2002 y2003 y2004 "
		local agreing "`agreing' y2005 y2101 y2201 y2202 y2203 y2204 yorf y2301 y2302 y2303 y2401 y2501 y2502 y2503 y2504 y2505 y2506 y2507 y2508 y2509 y2510 y280101 "	
		local agreing "`agreing' y280202  y280302 yinv0102 y2804 yesp0101 yesp0102 yesp y2604 y2701 yaut ysub1 ysub2 ysub ytot"


		foreach var of local agreing {
			gen `var'h = cond(nucleo!= 0 & `var'>0,`var',0)
		}

		local varjef "sexo edad condact ocupr ramar categ anoest"

		foreach var of local varjef {
			gen `var'j = cond(parentco==1,`var',-1)
		}

		sort id_hogar

		collapse (max) sexoj edadj anoestj condactj ocuprj ramarj categj (sum) pers-ytoth ,by(id_hogar) 

		rename anoestj educj

		save "`dir1'\\ca22temp", replace

	}



	if `part4' == 1 {

		noi display "Parte 4"
		/*AGREGA VARIABLES DE HOGAR AL ARCHIVO DB02 */

		use "`dir1'\\ca22dn02", clear

		sort id_hogar

		merge m:1 id_hogar using "`dir1'\\ca22temp"
		drop _merge

		compress

		/* Alquiler imputado*/

		gen yaimh = cond(parentco == 1 & v13!= 2 & v19>0 & v19!= ., v19, 0)
		bysort id_hogar: egen aux_yaimh = max(yaimh)
		bysort id_hogar: replace yaimh = aux_yaimh

		replace ytoth = ytoth + yaimh
		gen ypch = round(ytoth / persindo)


		drop aux_yaimh

		save "`dir1'\\ca22dn03", replace


		***********************************************************************************************
		******Creación de DN04: Corrección por no respuesta de ingresos de ocupados y jubilados********
		***********************************************************************************************

		use "`dir1'\\ca22dn03", clear

		gen paren1 = cond(parentco == 1, 1, 2)

		recode anoest (0/3 = 1) (4/7 = 2) (8/11 = 3) (12 = 4) (13/25 = 5) (99 = 1), into(niveduc)
		recode niveduc (1/3 = 1) (4/5 = 2), into(niveduc1)

		recode ramar (0 = 7) (-1 = -1) (1 = 1) (2 = 2) (3 6 = 3) (4 5 = 4) (7/10 = 5) (11/12 = 6) (13/21 = 7), into(ramar1)
		replace ramar1 = cond(categ == 8, .,ramar1)		/*en FFAA no se considera ni rama ni ocupación*/

		gen ramar2 = ramar
		replace ramar2 = cond(categ == 8, .,ramar)

		recode region (1/5 15 = 1) (6/12 14 16= 2) (13 = 13), into(reg1)

		recode edad (0/14 = 1) (15/24 = 2) (25/44 = 3) (45/64 = 4) (else = 5), into(tred1)
		recode edad (0/59 = 1) (60/69 = 2) (70/79 = 3) (else = 4), into(tredadam)

		recode categ (4 = 5) (6 = 7), into(categ1)
		recode categ1 (5 8 = 3), into(categ2) 

		recode ocupr (0 = 8) (5/7 10 = 5) (8 = 6) (9 = 7), into(ocupr1)
		replace ocupr1 = cond(categ == 1|categ == 8, ., ocupr1)			/*en empleadores no se considera ocupación*/ /*en FFAA no se considera ni rama ni ocupación*/


		/*Corrección ingresos de los ocupados*/

		/*Reemplazos en y1 y y7 para distinguir 0 y no responden de missing + generación de vbles para corte de colas (p1,p99)*/

		replace y0101 = .z if y1 == 0
		replace y0101 = .m if y1 == -88

		replace y0701 = .z if y7 == 0
		replace y0701 = .m if y7 == -88

		tabstat y0101 y0701 if y0101>0 & y0701>0, s(min p1 p50 p99 max) save f(%12.0f)
		mat YL = r(StatTotal)
		mat list YL

		gen y0101p1 = YL[2,1]
		gen y0101p99 = YL[4,1]
		gen y0701p1 = YL[2,2]
		gen y0701p99 = YL[4,2]


		gen y0101c = y0101
		gen y0701c = y0701

		local paso1 "comuna ramar2 tred1 categ 	niveduc  condact sexo ocupr1"
		local paso2 "region ramar2 tred1 categ 	niveduc  condact sexo ocupr1"
		local paso3 "region ramar1 tred1 categ 	niveduc  condact sexo ocupr1"
		local paso4 "region ramar1 tred1 categ1 niveduc  condact sexo ocupr1"
		local paso5 "region ramar1 tred1 categ1 niveduc1 condact sexo ocupr1"
		local paso6 "reg1 	ramar1 tred1 categ1 niveduc1 condact sexo ocupr1"
		local paso7 "reg1 	ramar1 tred1 categ2 niveduc1 condact sexo ocupr1"

		gen aux1_im = 1

		forval p = 1/7 {

			noi di _n(1) "Paso `p'"

			foreach v of var y0101 y0701 {
				preserve
				if "`v'" == "y0101" {
					keep if `v'>0 & `v'!=.m & `v'!=. & `v'!=.z & `v'>`v'p1 & `v'<`v'p99 & condact== 1 & categ>=3 & categ<=8
				}
				else if "`v'" == "y0701" {
					keep if `v'>0 & `v'!=.m & `v'!=. & `v'!=.z & `v'>`v'p1 & `v'<`v'p99 & condact== 1 & categ>=1 & categ<=2
				}
				collapse (mean) `v' [aw = factorex], by(`paso`p'')
				ren `v' _`v'
				save "`dir1'\\temp`p'_`v'", replace
				restore
			}

			noi di "Casos a imputar y0101"
			noi count if y0101c == .m & condact == 1 & categ>=3 & categ<=8   			/*Casos a imputar y0101*/

			tab aux1_im  if y0101c == .m & condact == 1 & categ>=3 & categ<=8, miss	
			local y0101c_`p' = r(N) // casos a imputar

			tab aux1_im  if y0101c != .m & (y0101c > 0 | y0101c == .z) & condact == 1 & categ>=3 & categ<=8, miss	
			local y0101c_`p'_inf = r(N) // casos con datos


			merge m:1 `paso`p'' using "`dir1'\\temp`p'_y0101"
			tab _merge
			replace y0101c = round(_y0101) if y0101c == .m & _merge == 3 & condact == 1 & categ>=3 & categ<=8 

			drop _merge

			noi di "Casos a imputar y0701"
			noi count if y0701c ==.m & condact == 1 & inlist(categ,1,2) 				/*Casos a imputar y0701*/
			tab aux1_im  if y0701c == .m & condact == 1 &  inlist(categ,1,2), m
			local y0701c_`p' = r(N) // casos a imputar

			tab aux1_im  if y0701c != .m & (y0701c > 0 | y0701c == .z) & condact == 1 & inlist(categ,1,2), miss	
			local y0701c_`p'_inf = r(N) // casos con datos

			merge m:1 `paso`p'' using "`dir1'\\temp`p'_y0701"
			tab _merge
			replace y0701c = round(_y0701) if y0701c ==.m & _merge == 3 & condact == 1 & inlist(categ,1,2) 
			drop _merge

			summ y0101 y0101c y0701 y0701c
			drop _y0101 _y0701
		}

		noi di "Casos sin imputar y0101"
		noi count if y0101c == .m & condact == 1 & categ>=3 & categ<=8   				/*Casos sin imputar y0101*/

		tab aux1_im  if y0101c == .m & condact == 1 & categ>=3 & categ<=8, miss	
		local y0101c_8 = r(N) // casos a imputar
		tab aux1_im  if y0101c != .m & (y0101c > 0 | y0101c == .z) & condact == 1 & categ>=3 & categ<=8, miss	
		local y0101c_8_inf = r(N) // casos con datos
		noi di "Casos sin imputar y0701"
		noi count if y0701c ==.m & condact == 1 & inlist(categ,1,2) 					/*Casos sin imputar y0701*/
		tab aux1_im  if y0701c == .m & condact == 1 &  inlist(categ,1,2), m
		local y0701c_8 = r(N) // casos a imputar

		tab aux1_im  if y0701c != .m & (y0701c > 0 | y0701c == .z) & condact == 1 & inlist(categ,1,2), miss	
		local y0701c_8_inf = r(N) // casos con datos

		cap log close 
		log using "`dir2'\\imputa_ocupados.log", text replace 
		noi display "var" _col(20) "P" _col(25)  "obs"   _col(45)   "NR"
		foreach v of var y0101c y0701c {
			forvalues p = 1/8{

				noi display "`v'" _col(20) `p' _col(25)  ``v'_`p'_inf'   _col(45)   ``v'_`p''

			}



		}

		cap log close
		log using "`dir2'\\generacion_ca22db06_2022.log", text append

		/*Corrección de jubilaciones y rentas vitalicias*/

		egen y2802 = rowtotal(y280201 y280202),m			/*Genera jubilación más aps*/
		egen y28031 = rowtotal(y280301 y280302),m 			/*Genera jubilación más pgu*/

		tabstat y2802 y28031 y2803 if y2802>0 & y28031>0 & y2803>0, s(min p1 p50 p99 max) save f(%12.0f)
		mat YJ = r(StatTotal)
		mat list YJ

		gen y2802p1 = YJ[2,1]
		gen y2802p99 = YJ[4,1]
		gen y28031p1 = YJ[2,2]
		gen y28031p99 = YJ[4,2]
		gen y2803p1 = YJ[2,3]
		gen y2803p99 = YJ[4,3]


		gen y280201c = y280201
		gen y280301c = y280301
		gen y2803c = y2803


		local paso1_jub "comuna paren1 sexo niveduc tredadam"
		local paso2_jub "region paren1 sexo niveduc tredadam"
		local paso3_jub "region paren1 sexo niveduc"


		forval p = 1/3 {

			noi di _n(1) "Paso `p' jub"

			foreach v of var y2802 y28031 y2803 {
				preserve

				if "`v'" == "y2802" {
					keep if `v'>0 & `v'!=.m & `v'!=. & `v'!= .z & `v'>`v'p1 & `v'<`v'p99 & y28_1b == 1
				}

				if "`v'" == "y28031" {
					keep if `v'>0 & `v'!=.m & `v'!=. & `v'!= .z & `v'>`v'p1 & `v'<`v'p99 & y28_1c == 1
				}

				if "`v'" == "y2803" {
					keep if `v'>0 & `v'!=.m & `v'!=. & `v'!= .z & `v'>`v'p1 & `v'<`v'p99 & y28_1c == 1
				}

				collapse (mean) `v' [aw = factorex], by(`paso`p'_jub')
				ren `v' _`v'
				save "`dir1'\\temp`p'_`v'", replace

				restore
			}

			noi di "Casos a imputar y2803"
			noi count if y2803c == .m  	/*Casos a imputar y2803*/
			tab aux1_im  if y2803c == .m , miss	
			local y2803c_`p' = r(N) // casos a imputar
			tab aux1_im  if y2803c != .m & (y2803c > 0 | y2803c == .z) & y2803c != . , miss	
			local y2803c_`p'_inf = r(N) // casos con datos

			noi di "Casos a imputar y280201"
			noi count if y280201c == .m	/*Casos a imputar y280201*/
			tab aux1_im  if y280201c == .m , miss	
			local y280201c_`p' = r(N) // casos a imputar
			tab aux1_im  if y280201c != .m & (y280201c > 0 | y280201c == .z) & y280201c != .  , miss	
			local y280201c_`p'_inf = r(N) // casos con datos
			noi di "Casos a imputar y280301"
			noi count if y280301c == .m  	/*Casos a imputar y280301*/
			tab aux1_im  if y280301c == .m , miss	
			local y280301c_`p' = r(N) // casos a imputar
			tab aux1_im  if y280301c != .m & (y280301c > 0 | y280301c == .z) & y280301c != .  , miss	
			local y280301c_`p'_inf = r(N) // casos con datos


			merge m:1 `paso`p'_jub' using "`dir1'\\temp`p'_y2802"
			tab _merge
			replace y280201c = round(_y2802) if y280201c == .m & (y280202 == .m | y280202 == .z | y280202 == .) & (y28031 == .m | y28031 == .z | y28031 == .) & (y2803 == .|y2803==.m |y2803==.z) & _merge == 3 & y28_1b == 1

			drop _merge

			merge m:1 `paso`p'_jub' using "`dir1'\\temp`p'_y28031"
			tab _merge
			replace y280301c = round(_y28031) if y280301c == .m & (y280302 == .m | y280302 == .z | y280302 == .) & (y2802 == .m | y2802 == .z | y2802 == .) & (y2803 == .|y2803==.m |y2803==.z) & _merge == 3 & y28_1c == 1

			drop _merge

			merge m:1 `paso`p'_jub' using "`dir1'\\temp`p'_y2803"
			tab _merge
			replace y2803c = round(_y2803) if y2803c == .m & _merge == 3 & y28_1c == 1

			drop _merge
			summ y2802 _y2802  y2803 _y2803 y28031 _y28031
			drop  _y2802 _y2803 _y28031  
		}

		noi di "Casos sin imputar y2803"
		noi count if y2803c == .m  	/*Casos sin imputar y2803*/
		tab aux1_im  if y2803c == .m , miss	
		local y2803c_4 = r(N) // casos a imputar
		tab aux1_im  if y2803c != .m & (y2803c > 0 | y2803c == .z)  & y2803c != . , miss	
		local y2803c_4_inf = r(N) // casos con datos

		noi di "Casos sin imputar y280201"
		noi count if y280201c == .m	/*Casos sin imputar y280201*/
		tab aux1_im  if y280201c == .m , miss	
		local y280201c_4 = r(N) // casos a imputar
		tab aux1_im  if y280201c != .m & (y280201c > 0 | y280201c == .z) & y280201c != . , miss	
		local y280201c_4_inf = r(N) // casos con datos

		noi di "Casos sin imputar y280301"
		noi count if y280301c == .m  	/*Casos sin imputar y280301*/
		tab aux1_im  if y280301c == .m , miss	
		local y280301c_4 = r(N) // casos a imputar
		tab aux1_im  if y280301c != .m & (y280301c > 0 | y280301c == .z) & y280301c != . , miss	
		local y280301c_4_inf = r(N) // casos con datos


		cap log close 
		log using "`dir2'\\imputa_jub_rv.log", text replace 
		noi display "var" _col(20) "P" _col(25)  "obs"   _col(45)   "NR"
		foreach v of var y2803c y280201c y280301c {
			forvalues p = 1/4{

				noi display "`v'" _col(20) `p' _col(25)  ``v'_`p'_inf'   _col(45)   ``v'_`p''

			}
		}

		cap log close
		log using "`dir2'\\generacion_ca22db06_2022.log", text append

		drop aux1_im	


		drop paren1 niveduc niveduc1 ramar1 ramar2 reg1 tred1 tredadam categ1 categ2 ocupr1 y2802 y2802p1 y2802p99 y2803p1 y2803p99 y28031p1  y28031p99 y28031 y0101p1 y0101p99 y0701p1 y0701p99


		/*Genera agregados corregidos*/

		egen yautcor = rowtotal(y0101c y0301 y0302 y0303 y0304 y0305 y0306 y0401 y0402 y0403 y0404 y0501 y0502 y0503 y0504 y0505 /*
			*/ y0506 y0507 y0508 y0509 y0510 y0511 y0512 yosa ytro yta1 y0701c y0801 y0901 yosi yta2 yrut yac2 ydes yids /*
		*/ yotr y280201c y280301c y2803c yinv0101 yinv02 ymon0101 ymon02 yorf yotp yre1 yre2 yre3 yama yah1 yah2 ydon ymes yfa1 yfa2 y1101 ydim),m

		egen ytotcor = rowtotal(yautcor ysub1 ysub2),m

		save "`dir1'\\ca22dn04", replace

	}

	if `part5' == 1 {
		noi display "Parte 5"
		*****************************************************************************************************************
		********"Creación DN05: crea agregados de ingreso corregidos nivel hogar y se incorporan a la base"**************
		*****************************************************************************************************************

		use "`dir1'\\ca22dn04", clear

		local agreingco "yautcor ytotcor y0101c y0701c y280201c y280301c y2803c"  

		foreach var of local agreingco {
			gen `var'h = cond(nucleo!= 0,`var',0)
		}	

		gen nrecep = cond(nucleo!= 0 & ytotcor>0 & ytotcor!=. , 1, 0)		/*Se genera número de perceptores de ingreso del hogar posterior a la corrección por no respuesta*/

		sort id_hogar
		collapse (sum) yautcorh ytotcorh nrecep y0101ch y0701ch y280201ch y280301ch y2803ch, by(id_hogar) 

		save "`dir1'\\ca22temp1", replace

		use "`dir1'\\ca22dn04", clear
		merge m:1 id_hogar using "`dir1'\\ca22temp1"
		tab _merge
		drop _merge


		save "`dir1'\\ca22dn05", replace
	}




	***************************************************************************************************
	***** "Creación de DN06: corrección de alquiler imputado y generación de variable de pobreza" ***** 
	***************************************************************************************************
	if `part6' == 1 {

		noi display "Parte 6"
		use "`dir1'\\ca22dn05.dta", clear

		/* Se genera el valor de la línea de pobreza e indigencia (Noviembre 2022)*/ 

		gen li= 144566
		gen lp= 216849


		/*Alquiler imputado*/

		/*Generación de matriz de alquiler*/

		gen v1_orig = v1

		gen v13_orig = v13
		replace v13= 1 if v13 == 1 & v13_propia == 1
		replace v13= 2 if v13 == 1 & v13_propia == 2
		replace v13= 3 if v13 == 1 & v13_propia == 3
		replace v13= 4 if v13 == 1 & v13_propia == 4
		replace v13= 5 if v13 == 2 & v13_arrendada == 5
		replace v13= 6 if v13 == 2 & v13_arrendada == 6
		replace v13= 7 if v13 == 3 & v13_cedida == 7
		replace v13= 8 if v13 == 3 & v13_cedida == 8

		label define sit_viv 1 "Propia pagada" 2 "Propia pagándose" 3 "Propia compartida (pagada) con otros hogares de la vivienda" /*
			*/4 "Propia compartida (pagándose) con otros hogares de la vivienda" 5 "Arrendada con contrato" 6 "Arrendada sin contrato" /*
			*/7 "Cedida por servicio o trabajo" 8 "Cedida por familiar u otro" 9 "Usufructo (sólo uso y goce)" 10 "Ocupación irregular (de hecho)" /*
		*/11 "Poseedor irregular"

		label value v13 sit_viv


		matrix YAIM = J(9,9,0)
		matrix rownames YAIM = 1 2 3 4 5 6 7 8 9 
		matrix colnames YAIM = 1 2 3 4 5 6 7 8 9	

		gen v19_orig = v19
		replace v19= 0 if v19==.

		sum v19 [aw=factorex] if parentco == 1 & v19 > 0 & v19 < ., d
		local v19_p1 = r(p1)
		local v19_p99 = r(p99)

		noi di "`v19_p1'" _col(30) "`v19_p99'"

		forval x = 1/9 {
			forval y = 1/9 {
				sum v19 [aw=factorex] if parentco == 1 & v1 ==`x' & v13 == `y' & v19> `v19_p1' & v19 < `v19_p99'
				if `y'!=5 & `y'!=6 {
					matrix YAIM[`x', `y'] = r(mean)
				}
				else {
					matrix YAIM[`x', `y'] = .
				}
			}
		}

		matrix list YAIM 


		gen yaicoh_aux = 0

		forval x = 1/9 {
			forval y = 1/9 {
				replace yaicoh_aux = YAIM[`x',`y'] if yaimh == 0 & v1 ==`x' & v13 == `y' & YAIM[`x',`y']>0 
				replace yaicoh_aux = YAIM[`x',1] if yaimh == 0 & v1 ==`x' & YAIM[`x',`y']<= 0
			}
		}

		preserve
		keep id_hogar yaimh v1 v13 parentco
		keep if parentco == 1

		gen y2 = yaimh
		sort v1 v13 id_hogar 
		by v1 v13: replace y2 = y2[_n-1] if y2 == 0 & y2[_n-1]!=0 & y2[_n-1]>`v19_p1' & y2[_n-1]<`v19_p99'

		save "`dir1'\\temp_ai.dta", replace

		sum yaimh          if yaimh == 0 & inlist(v13,1,2,3,4,7,8,9)
		sum y2                if y2 == 0 & inlist(v13,1,2,3,4,7,8,9)

		restore

		merge m:1 id_hogar using "`dir1'\\temp_ai", keepus(y2)

		gen yaimcorh = cond(inlist(v13,1,2,3,4,7,8,9),round(y2,1), 0)
		replace yaimcorh = 0 if yaimcorh == .
		replace yaimcorh = round(yaicoh_aux,1) if yaimcorh == 0 & inlist(v13,1,2,3,4,7,8,9)
		replace yaimcorh = 0 if y0503h > 0 & v13_cedida == 7                     /* En cedidas por servicio o trabajo se toma como alquiler imputado el pago en vivienda si este es mayor que cero */
		replace yaimcorh = 0 if yaimcorh == .

		sum yaimcorh if yaimcorh == 0 & inlist(v13,1,2,3,4,7,8,9)

		drop yaicoh_aux _merge y2

		replace ytotcorh = ytotcorh + yaimcorh


		/* Calculo  POBREZA*/ 

		gen ypc = round(ytotcorh /persindo)
		gen nae = persindo^0.7
		gen yae = round(ytotcorh / nae)

		gen pobreza = 3
		replace pobreza = 2 if yae < lp
		replace pobreza = 1 if yae < li

		label define pobreza 1 "Pobreza extrema" 2 "Pobreza no extrema" 3 "Fuera de la pobreza" 
		label values pobreza pobreza


		/* Se dejan variables de ingreso final y pobreza en 0 para nucleo==0*/

		replace ytotcorh = . if nucleo == 0
		replace ypc =. if nucleo == 0
		replace yae =. if nucleo == 0
		replace pobreza =. if nucleo == 0

		sort region area comuna /*segmento*/ id_vivienda id_hogar id_persona


		*do "`dir1'\_labels_chl22dn06.do" 
		save "`dir1'\\ca22dn06_CASEN", replace

		cap log close

		noi display "Finaliza"

	}
	scalar t2 = c(current_time)

	noi display (clock(t2, "hms") - clock(t1, "hms")) / 1000 " seconds"
}